import { Account, Address, KeyPairSigner, Signature } from '@solana/web3.js';
import { Client } from '@tensor-foundation/test-helpers';
import { AssetV1, CollectionV1, Creator, PluginAuthorityPairArgs } from '../generated';
export interface CreateAssetArgs {
    client: Client;
    payer: KeyPairSigner;
    authority?: KeyPairSigner;
    updateAuthority?: Address;
    owner: Address;
    name: string;
    uri: string;
    plugins: PluginAuthorityPairArgs[] | null;
    collection?: Address;
    asset_kp?: KeyPairSigner;
}
export interface CreateAssetResult {
    signature: Signature;
    address: Address;
}
export declare const createAsset: (args: CreateAssetArgs) => Promise<CreateAssetResult>;
export interface CreateDefaultAssetArgs {
    client: Client;
    payer: KeyPairSigner;
    authority?: KeyPairSigner;
    updateAuthority?: Address;
    owner: Address;
    royalties?: {
        creators: Creator[];
        basisPoints: number;
    };
    collection?: Address;
    name?: string;
    uri?: string;
}
export declare const createDefaultAsset: (args: CreateDefaultAssetArgs) => Promise<Account<AssetV1, Address>>;
export interface CreateCollectionArgs {
    client: Client;
    payer: KeyPairSigner;
    updateAuthority: Address;
    plugins: PluginAuthorityPairArgs[] | null;
    collection_kp?: KeyPairSigner;
}
export interface CreateCollectionResult {
    signature: Signature;
    address: Address;
}
export declare const createCollection: (args: CreateCollectionArgs) => Promise<CreateCollectionResult>;
export interface CreateDefaultCollectionArgs {
    client: Client;
    payer: KeyPairSigner;
    updateAuthority: Address;
    royalties?: {
        creators: Creator[];
        basisPoints: number;
    };
}
export declare const createDefaultCollection: (args: CreateDefaultCollectionArgs) => Promise<Account<CollectionV1, Address>>;
export interface CreateDefaultAssetWithCollectionArgs {
    client: Client;
    payer: KeyPairSigner;
    collectionAuthority: KeyPairSigner;
    owner: Address;
    royalties?: {
        creators: Creator[];
        basisPoints: number;
    };
    name?: string;
    uri?: string;
}
export declare const createDefaultAssetWithCollection: (args: CreateDefaultAssetWithCollectionArgs) => Promise<[Account<AssetV1, Address>, Account<CollectionV1, Address>]>;
//# sourceMappingURL=create.d.ts.map