'use strict';

var web3_js = require('@solana/web3.js');
var testHelpers = require('@tensor-foundation/test-helpers');

// src/generated/accounts/assetV1.ts
function getAddBlockerEncoder() {
  return web3_js.getStructEncoder([]);
}
function getAddBlockerDecoder() {
  return web3_js.getStructDecoder([]);
}
function getAddBlockerCodec() {
  return web3_js.combineCodec(getAddBlockerEncoder(), getAddBlockerDecoder());
}
function getAttributeEncoder() {
  return web3_js.getStructEncoder([
    ["key", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["value", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())]
  ]);
}
function getAttributeDecoder() {
  return web3_js.getStructDecoder([
    ["key", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["value", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())]
  ]);
}
function getAttributeCodec() {
  return web3_js.combineCodec(getAttributeEncoder(), getAttributeDecoder());
}
function getAttributesEncoder() {
  return web3_js.getStructEncoder([
    ["attributeList", web3_js.getArrayEncoder(getAttributeEncoder())]
  ]);
}
function getAttributesDecoder() {
  return web3_js.getStructDecoder([
    ["attributeList", web3_js.getArrayDecoder(getAttributeDecoder())]
  ]);
}
function getAttributesCodec() {
  return web3_js.combineCodec(getAttributesEncoder(), getAttributesDecoder());
}
function getAuthorityEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["None", web3_js.getUnitEncoder()],
    ["Owner", web3_js.getUnitEncoder()],
    ["UpdateAuthority", web3_js.getUnitEncoder()],
    ["Address", web3_js.getStructEncoder([["address", web3_js.getAddressEncoder()]])]
  ]);
}
function getAuthorityDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["None", web3_js.getUnitDecoder()],
    ["Owner", web3_js.getUnitDecoder()],
    ["UpdateAuthority", web3_js.getUnitDecoder()],
    ["Address", web3_js.getStructDecoder([["address", web3_js.getAddressDecoder()]])]
  ]);
}
function getAuthorityCodec() {
  return web3_js.combineCodec(getAuthorityEncoder(), getAuthorityDecoder());
}
function authority(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isAuthority(kind, value) {
  return value.__kind === kind;
}
function getAutographEncoder() {
  return web3_js.getStructEncoder([
    ["signatures", web3_js.getArrayEncoder(getAutographSignatureEncoder())]
  ]);
}
function getAutographDecoder() {
  return web3_js.getStructDecoder([
    ["signatures", web3_js.getArrayDecoder(getAutographSignatureDecoder())]
  ]);
}
function getAutographCodec() {
  return web3_js.combineCodec(getAutographEncoder(), getAutographDecoder());
}
function getAutographSignatureEncoder() {
  return web3_js.getStructEncoder([
    ["address", web3_js.getAddressEncoder()],
    ["message", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())]
  ]);
}
function getAutographSignatureDecoder() {
  return web3_js.getStructDecoder([
    ["address", web3_js.getAddressDecoder()],
    ["message", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())]
  ]);
}
function getAutographSignatureCodec() {
  return web3_js.combineCodec(
    getAutographSignatureEncoder(),
    getAutographSignatureDecoder()
  );
}
function getBurnDelegateEncoder() {
  return web3_js.getStructEncoder([]);
}
function getBurnDelegateDecoder() {
  return web3_js.getStructDecoder([]);
}
function getBurnDelegateCodec() {
  return web3_js.combineCodec(getBurnDelegateEncoder(), getBurnDelegateDecoder());
}
function getCompressionProofEncoder() {
  return web3_js.getStructEncoder([
    ["owner", web3_js.getAddressEncoder()],
    ["updateAuthority", getUpdateAuthorityEncoder()],
    ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["seq", web3_js.getU64Encoder()],
    ["plugins", web3_js.getArrayEncoder(getHashablePluginSchemaEncoder())]
  ]);
}
function getCompressionProofDecoder() {
  return web3_js.getStructDecoder([
    ["owner", web3_js.getAddressDecoder()],
    ["updateAuthority", getUpdateAuthorityDecoder()],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["seq", web3_js.getU64Decoder()],
    ["plugins", web3_js.getArrayDecoder(getHashablePluginSchemaDecoder())]
  ]);
}
function getCompressionProofCodec() {
  return web3_js.combineCodec(
    getCompressionProofEncoder(),
    getCompressionProofDecoder()
  );
}
function getCreatorEncoder() {
  return web3_js.getStructEncoder([
    ["address", web3_js.getAddressEncoder()],
    ["percentage", web3_js.getU8Encoder()]
  ]);
}
function getCreatorDecoder() {
  return web3_js.getStructDecoder([
    ["address", web3_js.getAddressDecoder()],
    ["percentage", web3_js.getU8Decoder()]
  ]);
}
function getCreatorCodec() {
  return web3_js.combineCodec(getCreatorEncoder(), getCreatorDecoder());
}
var DataState = /* @__PURE__ */ ((DataState2) => {
  DataState2[DataState2["AccountState"] = 0] = "AccountState";
  DataState2[DataState2["LedgerState"] = 1] = "LedgerState";
  return DataState2;
})(DataState || {});
function getDataStateEncoder() {
  return web3_js.getEnumEncoder(DataState);
}
function getDataStateDecoder() {
  return web3_js.getEnumDecoder(DataState);
}
function getDataStateCodec() {
  return web3_js.combineCodec(getDataStateEncoder(), getDataStateDecoder());
}
function getDataStoreEncoder() {
  return web3_js.getStructEncoder([
    ["dataAuthority", getAuthorityEncoder()],
    ["schema", getExternalPluginAdapterSchemaEncoder()]
  ]);
}
function getDataStoreDecoder() {
  return web3_js.getStructDecoder([
    ["dataAuthority", getAuthorityDecoder()],
    ["schema", getExternalPluginAdapterSchemaDecoder()]
  ]);
}
function getDataStoreCodec() {
  return web3_js.combineCodec(getDataStoreEncoder(), getDataStoreDecoder());
}
function getDataStoreInitInfoEncoder() {
  return web3_js.getStructEncoder([
    ["dataAuthority", getAuthorityEncoder()],
    ["initPluginAuthority", web3_js.getOptionEncoder(getAuthorityEncoder())],
    ["schema", web3_js.getOptionEncoder(getExternalPluginAdapterSchemaEncoder())]
  ]);
}
function getDataStoreInitInfoDecoder() {
  return web3_js.getStructDecoder([
    ["dataAuthority", getAuthorityDecoder()],
    ["initPluginAuthority", web3_js.getOptionDecoder(getAuthorityDecoder())],
    ["schema", web3_js.getOptionDecoder(getExternalPluginAdapterSchemaDecoder())]
  ]);
}
function getDataStoreInitInfoCodec() {
  return web3_js.combineCodec(
    getDataStoreInitInfoEncoder(),
    getDataStoreInitInfoDecoder()
  );
}
function getDataStoreUpdateInfoEncoder() {
  return web3_js.getStructEncoder([
    ["schema", web3_js.getOptionEncoder(getExternalPluginAdapterSchemaEncoder())]
  ]);
}
function getDataStoreUpdateInfoDecoder() {
  return web3_js.getStructDecoder([
    ["schema", web3_js.getOptionDecoder(getExternalPluginAdapterSchemaDecoder())]
  ]);
}
function getDataStoreUpdateInfoCodec() {
  return web3_js.combineCodec(
    getDataStoreUpdateInfoEncoder(),
    getDataStoreUpdateInfoDecoder()
  );
}
function getEditionEncoder() {
  return web3_js.getStructEncoder([["number", web3_js.getU32Encoder()]]);
}
function getEditionDecoder() {
  return web3_js.getStructDecoder([["number", web3_js.getU32Decoder()]]);
}
function getEditionCodec() {
  return web3_js.combineCodec(getEditionEncoder(), getEditionDecoder());
}
function getExternalCheckResultEncoder() {
  return web3_js.getStructEncoder([["flags", web3_js.getU32Encoder()]]);
}
function getExternalCheckResultDecoder() {
  return web3_js.getStructDecoder([["flags", web3_js.getU32Decoder()]]);
}
function getExternalCheckResultCodec() {
  return web3_js.combineCodec(
    getExternalCheckResultEncoder(),
    getExternalCheckResultDecoder()
  );
}
function getExternalPluginAdapterEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "LifecycleHook",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getLifecycleHookEncoder()])]
      ])
    ],
    [
      "Oracle",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getOracleEncoder()])]])
    ],
    [
      "DataStore",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getDataStoreEncoder()])]])
    ]
  ]);
}
function getExternalPluginAdapterDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "LifecycleHook",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getLifecycleHookDecoder()])]
      ])
    ],
    [
      "Oracle",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getOracleDecoder()])]])
    ],
    [
      "DataStore",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getDataStoreDecoder()])]])
    ]
  ]);
}
function getExternalPluginAdapterCodec() {
  return web3_js.combineCodec(
    getExternalPluginAdapterEncoder(),
    getExternalPluginAdapterDecoder()
  );
}
function externalPluginAdapter(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isExternalPluginAdapter(kind, value) {
  return value.__kind === kind;
}
function getExternalPluginAdapterInitInfoEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "LifecycleHook",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getLifecycleHookInitInfoEncoder()])]
      ])
    ],
    [
      "Oracle",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getOracleInitInfoEncoder()])]
      ])
    ],
    [
      "DataStore",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getDataStoreInitInfoEncoder()])]
      ])
    ]
  ]);
}
function getExternalPluginAdapterInitInfoDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "LifecycleHook",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getLifecycleHookInitInfoDecoder()])]
      ])
    ],
    [
      "Oracle",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getOracleInitInfoDecoder()])]
      ])
    ],
    [
      "DataStore",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getDataStoreInitInfoDecoder()])]
      ])
    ]
  ]);
}
function getExternalPluginAdapterInitInfoCodec() {
  return web3_js.combineCodec(
    getExternalPluginAdapterInitInfoEncoder(),
    getExternalPluginAdapterInitInfoDecoder()
  );
}
function externalPluginAdapterInitInfo(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isExternalPluginAdapterInitInfo(kind, value) {
  return value.__kind === kind;
}
function getExternalPluginAdapterKeyEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "LifecycleHook",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getAddressEncoder()])]])
    ],
    [
      "Oracle",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getAddressEncoder()])]])
    ],
    [
      "DataStore",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getAuthorityEncoder()])]])
    ]
  ]);
}
function getExternalPluginAdapterKeyDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "LifecycleHook",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getAddressDecoder()])]])
    ],
    [
      "Oracle",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getAddressDecoder()])]])
    ],
    [
      "DataStore",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getAuthorityDecoder()])]])
    ]
  ]);
}
function getExternalPluginAdapterKeyCodec() {
  return web3_js.combineCodec(
    getExternalPluginAdapterKeyEncoder(),
    getExternalPluginAdapterKeyDecoder()
  );
}
function externalPluginAdapterKey(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isExternalPluginAdapterKey(kind, value) {
  return value.__kind === kind;
}
var ExternalPluginAdapterSchema = /* @__PURE__ */ ((ExternalPluginAdapterSchema2) => {
  ExternalPluginAdapterSchema2[ExternalPluginAdapterSchema2["Binary"] = 0] = "Binary";
  ExternalPluginAdapterSchema2[ExternalPluginAdapterSchema2["Json"] = 1] = "Json";
  ExternalPluginAdapterSchema2[ExternalPluginAdapterSchema2["MsgPack"] = 2] = "MsgPack";
  return ExternalPluginAdapterSchema2;
})(ExternalPluginAdapterSchema || {});
function getExternalPluginAdapterSchemaEncoder() {
  return web3_js.getEnumEncoder(ExternalPluginAdapterSchema);
}
function getExternalPluginAdapterSchemaDecoder() {
  return web3_js.getEnumDecoder(ExternalPluginAdapterSchema);
}
function getExternalPluginAdapterSchemaCodec() {
  return web3_js.combineCodec(
    getExternalPluginAdapterSchemaEncoder(),
    getExternalPluginAdapterSchemaDecoder()
  );
}
var ExternalPluginAdapterType = /* @__PURE__ */ ((ExternalPluginAdapterType2) => {
  ExternalPluginAdapterType2[ExternalPluginAdapterType2["LifecycleHook"] = 0] = "LifecycleHook";
  ExternalPluginAdapterType2[ExternalPluginAdapterType2["Oracle"] = 1] = "Oracle";
  ExternalPluginAdapterType2[ExternalPluginAdapterType2["DataStore"] = 2] = "DataStore";
  return ExternalPluginAdapterType2;
})(ExternalPluginAdapterType || {});
function getExternalPluginAdapterTypeEncoder() {
  return web3_js.getEnumEncoder(ExternalPluginAdapterType);
}
function getExternalPluginAdapterTypeDecoder() {
  return web3_js.getEnumDecoder(ExternalPluginAdapterType);
}
function getExternalPluginAdapterTypeCodec() {
  return web3_js.combineCodec(
    getExternalPluginAdapterTypeEncoder(),
    getExternalPluginAdapterTypeDecoder()
  );
}
function getExternalPluginAdapterUpdateInfoEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "LifecycleHook",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getLifecycleHookUpdateInfoEncoder()])]
      ])
    ],
    [
      "Oracle",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getOracleUpdateInfoEncoder()])]
      ])
    ],
    [
      "DataStore",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getDataStoreUpdateInfoEncoder()])]
      ])
    ]
  ]);
}
function getExternalPluginAdapterUpdateInfoDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "LifecycleHook",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getLifecycleHookUpdateInfoDecoder()])]
      ])
    ],
    [
      "Oracle",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getOracleUpdateInfoDecoder()])]
      ])
    ],
    [
      "DataStore",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getDataStoreUpdateInfoDecoder()])]
      ])
    ]
  ]);
}
function getExternalPluginAdapterUpdateInfoCodec() {
  return web3_js.combineCodec(
    getExternalPluginAdapterUpdateInfoEncoder(),
    getExternalPluginAdapterUpdateInfoDecoder()
  );
}
function externalPluginAdapterUpdateInfo(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isExternalPluginAdapterUpdateInfo(kind, value) {
  return value.__kind === kind;
}
function getExternalRegistryRecordEncoder() {
  return web3_js.getStructEncoder([
    ["pluginType", getExternalPluginAdapterTypeEncoder()],
    ["authority", getAuthorityEncoder()],
    [
      "lifecycleChecks",
      web3_js.getOptionEncoder(
        web3_js.getArrayEncoder(
          web3_js.getTupleEncoder([
            getHookableLifecycleEventEncoder(),
            getExternalCheckResultEncoder()
          ])
        )
      )
    ],
    ["offset", web3_js.getU64Encoder()],
    ["dataOffset", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
    ["dataLen", web3_js.getOptionEncoder(web3_js.getU64Encoder())]
  ]);
}
function getExternalRegistryRecordDecoder() {
  return web3_js.getStructDecoder([
    ["pluginType", getExternalPluginAdapterTypeDecoder()],
    ["authority", getAuthorityDecoder()],
    [
      "lifecycleChecks",
      web3_js.getOptionDecoder(
        web3_js.getArrayDecoder(
          web3_js.getTupleDecoder([
            getHookableLifecycleEventDecoder(),
            getExternalCheckResultDecoder()
          ])
        )
      )
    ],
    ["offset", web3_js.getU64Decoder()],
    ["dataOffset", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["dataLen", web3_js.getOptionDecoder(web3_js.getU64Decoder())]
  ]);
}
function getExternalRegistryRecordCodec() {
  return web3_js.combineCodec(
    getExternalRegistryRecordEncoder(),
    getExternalRegistryRecordDecoder()
  );
}
var ExternalValidationResult = /* @__PURE__ */ ((ExternalValidationResult2) => {
  ExternalValidationResult2[ExternalValidationResult2["Approved"] = 0] = "Approved";
  ExternalValidationResult2[ExternalValidationResult2["Rejected"] = 1] = "Rejected";
  ExternalValidationResult2[ExternalValidationResult2["Pass"] = 2] = "Pass";
  return ExternalValidationResult2;
})(ExternalValidationResult || {});
function getExternalValidationResultEncoder() {
  return web3_js.getEnumEncoder(ExternalValidationResult);
}
function getExternalValidationResultDecoder() {
  return web3_js.getEnumDecoder(ExternalValidationResult);
}
function getExternalValidationResultCodec() {
  return web3_js.combineCodec(
    getExternalValidationResultEncoder(),
    getExternalValidationResultDecoder()
  );
}
function getExtraAccountEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "PreconfiguredProgram",
      web3_js.getStructEncoder([
        ["isSigner", web3_js.getBooleanEncoder()],
        ["isWritable", web3_js.getBooleanEncoder()]
      ])
    ],
    [
      "PreconfiguredCollection",
      web3_js.getStructEncoder([
        ["isSigner", web3_js.getBooleanEncoder()],
        ["isWritable", web3_js.getBooleanEncoder()]
      ])
    ],
    [
      "PreconfiguredOwner",
      web3_js.getStructEncoder([
        ["isSigner", web3_js.getBooleanEncoder()],
        ["isWritable", web3_js.getBooleanEncoder()]
      ])
    ],
    [
      "PreconfiguredRecipient",
      web3_js.getStructEncoder([
        ["isSigner", web3_js.getBooleanEncoder()],
        ["isWritable", web3_js.getBooleanEncoder()]
      ])
    ],
    [
      "PreconfiguredAsset",
      web3_js.getStructEncoder([
        ["isSigner", web3_js.getBooleanEncoder()],
        ["isWritable", web3_js.getBooleanEncoder()]
      ])
    ],
    [
      "CustomPda",
      web3_js.getStructEncoder([
        ["seeds", web3_js.getArrayEncoder(getSeedEncoder())],
        ["customProgramId", web3_js.getOptionEncoder(web3_js.getAddressEncoder())],
        ["isSigner", web3_js.getBooleanEncoder()],
        ["isWritable", web3_js.getBooleanEncoder()]
      ])
    ],
    [
      "Address",
      web3_js.getStructEncoder([
        ["address", web3_js.getAddressEncoder()],
        ["isSigner", web3_js.getBooleanEncoder()],
        ["isWritable", web3_js.getBooleanEncoder()]
      ])
    ]
  ]);
}
function getExtraAccountDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "PreconfiguredProgram",
      web3_js.getStructDecoder([
        ["isSigner", web3_js.getBooleanDecoder()],
        ["isWritable", web3_js.getBooleanDecoder()]
      ])
    ],
    [
      "PreconfiguredCollection",
      web3_js.getStructDecoder([
        ["isSigner", web3_js.getBooleanDecoder()],
        ["isWritable", web3_js.getBooleanDecoder()]
      ])
    ],
    [
      "PreconfiguredOwner",
      web3_js.getStructDecoder([
        ["isSigner", web3_js.getBooleanDecoder()],
        ["isWritable", web3_js.getBooleanDecoder()]
      ])
    ],
    [
      "PreconfiguredRecipient",
      web3_js.getStructDecoder([
        ["isSigner", web3_js.getBooleanDecoder()],
        ["isWritable", web3_js.getBooleanDecoder()]
      ])
    ],
    [
      "PreconfiguredAsset",
      web3_js.getStructDecoder([
        ["isSigner", web3_js.getBooleanDecoder()],
        ["isWritable", web3_js.getBooleanDecoder()]
      ])
    ],
    [
      "CustomPda",
      web3_js.getStructDecoder([
        ["seeds", web3_js.getArrayDecoder(getSeedDecoder())],
        ["customProgramId", web3_js.getOptionDecoder(web3_js.getAddressDecoder())],
        ["isSigner", web3_js.getBooleanDecoder()],
        ["isWritable", web3_js.getBooleanDecoder()]
      ])
    ],
    [
      "Address",
      web3_js.getStructDecoder([
        ["address", web3_js.getAddressDecoder()],
        ["isSigner", web3_js.getBooleanDecoder()],
        ["isWritable", web3_js.getBooleanDecoder()]
      ])
    ]
  ]);
}
function getExtraAccountCodec() {
  return web3_js.combineCodec(getExtraAccountEncoder(), getExtraAccountDecoder());
}
function extraAccount(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isExtraAccount(kind, value) {
  return value.__kind === kind;
}
function getFreezeDelegateEncoder() {
  return web3_js.getStructEncoder([["frozen", web3_js.getBooleanEncoder()]]);
}
function getFreezeDelegateDecoder() {
  return web3_js.getStructDecoder([["frozen", web3_js.getBooleanDecoder()]]);
}
function getFreezeDelegateCodec() {
  return web3_js.combineCodec(getFreezeDelegateEncoder(), getFreezeDelegateDecoder());
}
function getHashablePluginSchemaEncoder() {
  return web3_js.getStructEncoder([
    ["index", web3_js.getU64Encoder()],
    ["authority", getAuthorityEncoder()],
    ["plugin", getPluginEncoder()]
  ]);
}
function getHashablePluginSchemaDecoder() {
  return web3_js.getStructDecoder([
    ["index", web3_js.getU64Decoder()],
    ["authority", getAuthorityDecoder()],
    ["plugin", getPluginDecoder()]
  ]);
}
function getHashablePluginSchemaCodec() {
  return web3_js.combineCodec(
    getHashablePluginSchemaEncoder(),
    getHashablePluginSchemaDecoder()
  );
}
function getHashedAssetSchemaEncoder() {
  return web3_js.getStructEncoder([
    ["assetHash", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)],
    ["pluginHashes", web3_js.getArrayEncoder(web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32))]
  ]);
}
function getHashedAssetSchemaDecoder() {
  return web3_js.getStructDecoder([
    ["assetHash", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)],
    ["pluginHashes", web3_js.getArrayDecoder(web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32))]
  ]);
}
function getHashedAssetSchemaCodec() {
  return web3_js.combineCodec(
    getHashedAssetSchemaEncoder(),
    getHashedAssetSchemaDecoder()
  );
}
var HookableLifecycleEvent = /* @__PURE__ */ ((HookableLifecycleEvent2) => {
  HookableLifecycleEvent2[HookableLifecycleEvent2["Create"] = 0] = "Create";
  HookableLifecycleEvent2[HookableLifecycleEvent2["Transfer"] = 1] = "Transfer";
  HookableLifecycleEvent2[HookableLifecycleEvent2["Burn"] = 2] = "Burn";
  HookableLifecycleEvent2[HookableLifecycleEvent2["Update"] = 3] = "Update";
  return HookableLifecycleEvent2;
})(HookableLifecycleEvent || {});
function getHookableLifecycleEventEncoder() {
  return web3_js.getEnumEncoder(HookableLifecycleEvent);
}
function getHookableLifecycleEventDecoder() {
  return web3_js.getEnumDecoder(HookableLifecycleEvent);
}
function getHookableLifecycleEventCodec() {
  return web3_js.combineCodec(
    getHookableLifecycleEventEncoder(),
    getHookableLifecycleEventDecoder()
  );
}
function getImmutableMetadataEncoder() {
  return web3_js.getStructEncoder([]);
}
function getImmutableMetadataDecoder() {
  return web3_js.getStructDecoder([]);
}
function getImmutableMetadataCodec() {
  return web3_js.combineCodec(
    getImmutableMetadataEncoder(),
    getImmutableMetadataDecoder()
  );
}
var Key = /* @__PURE__ */ ((Key2) => {
  Key2[Key2["Uninitialized"] = 0] = "Uninitialized";
  Key2[Key2["AssetV1"] = 1] = "AssetV1";
  Key2[Key2["HashedAssetV1"] = 2] = "HashedAssetV1";
  Key2[Key2["PluginHeaderV1"] = 3] = "PluginHeaderV1";
  Key2[Key2["PluginRegistryV1"] = 4] = "PluginRegistryV1";
  Key2[Key2["CollectionV1"] = 5] = "CollectionV1";
  return Key2;
})(Key || {});
function getKeyEncoder() {
  return web3_js.getEnumEncoder(Key);
}
function getKeyDecoder() {
  return web3_js.getEnumDecoder(Key);
}
function getKeyCodec() {
  return web3_js.combineCodec(getKeyEncoder(), getKeyDecoder());
}
function getLifecycleHookEncoder() {
  return web3_js.getStructEncoder([
    ["hookedProgram", web3_js.getAddressEncoder()],
    [
      "extraAccounts",
      web3_js.getOptionEncoder(web3_js.getArrayEncoder(getExtraAccountEncoder()))
    ],
    ["dataAuthority", web3_js.getOptionEncoder(getAuthorityEncoder())],
    ["schema", getExternalPluginAdapterSchemaEncoder()]
  ]);
}
function getLifecycleHookDecoder() {
  return web3_js.getStructDecoder([
    ["hookedProgram", web3_js.getAddressDecoder()],
    [
      "extraAccounts",
      web3_js.getOptionDecoder(web3_js.getArrayDecoder(getExtraAccountDecoder()))
    ],
    ["dataAuthority", web3_js.getOptionDecoder(getAuthorityDecoder())],
    ["schema", getExternalPluginAdapterSchemaDecoder()]
  ]);
}
function getLifecycleHookCodec() {
  return web3_js.combineCodec(getLifecycleHookEncoder(), getLifecycleHookDecoder());
}
function getLifecycleHookInitInfoEncoder() {
  return web3_js.getStructEncoder([
    ["hookedProgram", web3_js.getAddressEncoder()],
    ["initPluginAuthority", web3_js.getOptionEncoder(getAuthorityEncoder())],
    [
      "lifecycleChecks",
      web3_js.getArrayEncoder(
        web3_js.getTupleEncoder([
          getHookableLifecycleEventEncoder(),
          getExternalCheckResultEncoder()
        ])
      )
    ],
    [
      "extraAccounts",
      web3_js.getOptionEncoder(web3_js.getArrayEncoder(getExtraAccountEncoder()))
    ],
    ["dataAuthority", web3_js.getOptionEncoder(getAuthorityEncoder())],
    ["schema", web3_js.getOptionEncoder(getExternalPluginAdapterSchemaEncoder())]
  ]);
}
function getLifecycleHookInitInfoDecoder() {
  return web3_js.getStructDecoder([
    ["hookedProgram", web3_js.getAddressDecoder()],
    ["initPluginAuthority", web3_js.getOptionDecoder(getAuthorityDecoder())],
    [
      "lifecycleChecks",
      web3_js.getArrayDecoder(
        web3_js.getTupleDecoder([
          getHookableLifecycleEventDecoder(),
          getExternalCheckResultDecoder()
        ])
      )
    ],
    [
      "extraAccounts",
      web3_js.getOptionDecoder(web3_js.getArrayDecoder(getExtraAccountDecoder()))
    ],
    ["dataAuthority", web3_js.getOptionDecoder(getAuthorityDecoder())],
    ["schema", web3_js.getOptionDecoder(getExternalPluginAdapterSchemaDecoder())]
  ]);
}
function getLifecycleHookInitInfoCodec() {
  return web3_js.combineCodec(
    getLifecycleHookInitInfoEncoder(),
    getLifecycleHookInitInfoDecoder()
  );
}
function getLifecycleHookUpdateInfoEncoder() {
  return web3_js.getStructEncoder([
    [
      "lifecycleChecks",
      web3_js.getOptionEncoder(
        web3_js.getArrayEncoder(
          web3_js.getTupleEncoder([
            getHookableLifecycleEventEncoder(),
            getExternalCheckResultEncoder()
          ])
        )
      )
    ],
    [
      "extraAccounts",
      web3_js.getOptionEncoder(web3_js.getArrayEncoder(getExtraAccountEncoder()))
    ],
    ["schema", web3_js.getOptionEncoder(getExternalPluginAdapterSchemaEncoder())]
  ]);
}
function getLifecycleHookUpdateInfoDecoder() {
  return web3_js.getStructDecoder([
    [
      "lifecycleChecks",
      web3_js.getOptionDecoder(
        web3_js.getArrayDecoder(
          web3_js.getTupleDecoder([
            getHookableLifecycleEventDecoder(),
            getExternalCheckResultDecoder()
          ])
        )
      )
    ],
    [
      "extraAccounts",
      web3_js.getOptionDecoder(web3_js.getArrayDecoder(getExtraAccountDecoder()))
    ],
    ["schema", web3_js.getOptionDecoder(getExternalPluginAdapterSchemaDecoder())]
  ]);
}
function getLifecycleHookUpdateInfoCodec() {
  return web3_js.combineCodec(
    getLifecycleHookUpdateInfoEncoder(),
    getLifecycleHookUpdateInfoDecoder()
  );
}
function getMasterEditionEncoder() {
  return web3_js.getStructEncoder([
    ["maxSupply", web3_js.getOptionEncoder(web3_js.getU32Encoder())],
    [
      "name",
      web3_js.getOptionEncoder(web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder()))
    ],
    [
      "uri",
      web3_js.getOptionEncoder(web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder()))
    ]
  ]);
}
function getMasterEditionDecoder() {
  return web3_js.getStructDecoder([
    ["maxSupply", web3_js.getOptionDecoder(web3_js.getU32Decoder())],
    [
      "name",
      web3_js.getOptionDecoder(web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder()))
    ],
    [
      "uri",
      web3_js.getOptionDecoder(web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder()))
    ]
  ]);
}
function getMasterEditionCodec() {
  return web3_js.combineCodec(getMasterEditionEncoder(), getMasterEditionDecoder());
}
function getOracleEncoder() {
  return web3_js.getStructEncoder([
    ["baseAddress", web3_js.getAddressEncoder()],
    ["baseAddressConfig", web3_js.getOptionEncoder(getExtraAccountEncoder())],
    ["resultsOffset", getValidationResultsOffsetEncoder()]
  ]);
}
function getOracleDecoder() {
  return web3_js.getStructDecoder([
    ["baseAddress", web3_js.getAddressDecoder()],
    ["baseAddressConfig", web3_js.getOptionDecoder(getExtraAccountDecoder())],
    ["resultsOffset", getValidationResultsOffsetDecoder()]
  ]);
}
function getOracleCodec() {
  return web3_js.combineCodec(getOracleEncoder(), getOracleDecoder());
}
function getOracleInitInfoEncoder() {
  return web3_js.getStructEncoder([
    ["baseAddress", web3_js.getAddressEncoder()],
    ["initPluginAuthority", web3_js.getOptionEncoder(getAuthorityEncoder())],
    [
      "lifecycleChecks",
      web3_js.getArrayEncoder(
        web3_js.getTupleEncoder([
          getHookableLifecycleEventEncoder(),
          getExternalCheckResultEncoder()
        ])
      )
    ],
    ["baseAddressConfig", web3_js.getOptionEncoder(getExtraAccountEncoder())],
    ["resultsOffset", web3_js.getOptionEncoder(getValidationResultsOffsetEncoder())]
  ]);
}
function getOracleInitInfoDecoder() {
  return web3_js.getStructDecoder([
    ["baseAddress", web3_js.getAddressDecoder()],
    ["initPluginAuthority", web3_js.getOptionDecoder(getAuthorityDecoder())],
    [
      "lifecycleChecks",
      web3_js.getArrayDecoder(
        web3_js.getTupleDecoder([
          getHookableLifecycleEventDecoder(),
          getExternalCheckResultDecoder()
        ])
      )
    ],
    ["baseAddressConfig", web3_js.getOptionDecoder(getExtraAccountDecoder())],
    ["resultsOffset", web3_js.getOptionDecoder(getValidationResultsOffsetDecoder())]
  ]);
}
function getOracleInitInfoCodec() {
  return web3_js.combineCodec(getOracleInitInfoEncoder(), getOracleInitInfoDecoder());
}
function getOracleUpdateInfoEncoder() {
  return web3_js.getStructEncoder([
    [
      "lifecycleChecks",
      web3_js.getOptionEncoder(
        web3_js.getArrayEncoder(
          web3_js.getTupleEncoder([
            getHookableLifecycleEventEncoder(),
            getExternalCheckResultEncoder()
          ])
        )
      )
    ],
    ["baseAddressConfig", web3_js.getOptionEncoder(getExtraAccountEncoder())],
    ["resultsOffset", web3_js.getOptionEncoder(getValidationResultsOffsetEncoder())]
  ]);
}
function getOracleUpdateInfoDecoder() {
  return web3_js.getStructDecoder([
    [
      "lifecycleChecks",
      web3_js.getOptionDecoder(
        web3_js.getArrayDecoder(
          web3_js.getTupleDecoder([
            getHookableLifecycleEventDecoder(),
            getExternalCheckResultDecoder()
          ])
        )
      )
    ],
    ["baseAddressConfig", web3_js.getOptionDecoder(getExtraAccountDecoder())],
    ["resultsOffset", web3_js.getOptionDecoder(getValidationResultsOffsetDecoder())]
  ]);
}
function getOracleUpdateInfoCodec() {
  return web3_js.combineCodec(
    getOracleUpdateInfoEncoder(),
    getOracleUpdateInfoDecoder()
  );
}
function getOracleValidationEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["Uninitialized", web3_js.getUnitEncoder()],
    [
      "V1",
      web3_js.getStructEncoder([
        ["create", getExternalValidationResultEncoder()],
        ["transfer", getExternalValidationResultEncoder()],
        ["burn", getExternalValidationResultEncoder()],
        ["update", getExternalValidationResultEncoder()]
      ])
    ]
  ]);
}
function getOracleValidationDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["Uninitialized", web3_js.getUnitDecoder()],
    [
      "V1",
      web3_js.getStructDecoder([
        ["create", getExternalValidationResultDecoder()],
        ["transfer", getExternalValidationResultDecoder()],
        ["burn", getExternalValidationResultDecoder()],
        ["update", getExternalValidationResultDecoder()]
      ])
    ]
  ]);
}
function getOracleValidationCodec() {
  return web3_js.combineCodec(
    getOracleValidationEncoder(),
    getOracleValidationDecoder()
  );
}
function oracleValidation(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isOracleValidation(kind, value) {
  return value.__kind === kind;
}
function getPermanentBurnDelegateEncoder() {
  return web3_js.getStructEncoder([]);
}
function getPermanentBurnDelegateDecoder() {
  return web3_js.getStructDecoder([]);
}
function getPermanentBurnDelegateCodec() {
  return web3_js.combineCodec(
    getPermanentBurnDelegateEncoder(),
    getPermanentBurnDelegateDecoder()
  );
}
function getPermanentFreezeDelegateEncoder() {
  return web3_js.getStructEncoder([["frozen", web3_js.getBooleanEncoder()]]);
}
function getPermanentFreezeDelegateDecoder() {
  return web3_js.getStructDecoder([["frozen", web3_js.getBooleanDecoder()]]);
}
function getPermanentFreezeDelegateCodec() {
  return web3_js.combineCodec(
    getPermanentFreezeDelegateEncoder(),
    getPermanentFreezeDelegateDecoder()
  );
}
function getPermanentTransferDelegateEncoder() {
  return web3_js.getStructEncoder([]);
}
function getPermanentTransferDelegateDecoder() {
  return web3_js.getStructDecoder([]);
}
function getPermanentTransferDelegateCodec() {
  return web3_js.combineCodec(
    getPermanentTransferDelegateEncoder(),
    getPermanentTransferDelegateDecoder()
  );
}
function getPluginEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "Royalties",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getRoyaltiesEncoder()])]])
    ],
    [
      "FreezeDelegate",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getFreezeDelegateEncoder()])]
      ])
    ],
    [
      "BurnDelegate",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getBurnDelegateEncoder()])]
      ])
    ],
    [
      "TransferDelegate",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getTransferDelegateEncoder()])]
      ])
    ],
    [
      "UpdateDelegate",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getUpdateDelegateEncoder()])]
      ])
    ],
    [
      "PermanentFreezeDelegate",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getPermanentFreezeDelegateEncoder()])]
      ])
    ],
    [
      "Attributes",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getAttributesEncoder()])]])
    ],
    [
      "PermanentTransferDelegate",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getPermanentTransferDelegateEncoder()])]
      ])
    ],
    [
      "PermanentBurnDelegate",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getPermanentBurnDelegateEncoder()])]
      ])
    ],
    [
      "Edition",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getEditionEncoder()])]])
    ],
    [
      "MasterEdition",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getMasterEditionEncoder()])]
      ])
    ],
    [
      "AddBlocker",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getAddBlockerEncoder()])]])
    ],
    [
      "ImmutableMetadata",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getImmutableMetadataEncoder()])]
      ])
    ],
    [
      "VerifiedCreators",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getVerifiedCreatorsEncoder()])]
      ])
    ],
    [
      "Autograph",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getAutographEncoder()])]])
    ]
  ]);
}
function getPluginDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "Royalties",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getRoyaltiesDecoder()])]])
    ],
    [
      "FreezeDelegate",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getFreezeDelegateDecoder()])]
      ])
    ],
    [
      "BurnDelegate",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getBurnDelegateDecoder()])]
      ])
    ],
    [
      "TransferDelegate",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getTransferDelegateDecoder()])]
      ])
    ],
    [
      "UpdateDelegate",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getUpdateDelegateDecoder()])]
      ])
    ],
    [
      "PermanentFreezeDelegate",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getPermanentFreezeDelegateDecoder()])]
      ])
    ],
    [
      "Attributes",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getAttributesDecoder()])]])
    ],
    [
      "PermanentTransferDelegate",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getPermanentTransferDelegateDecoder()])]
      ])
    ],
    [
      "PermanentBurnDelegate",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getPermanentBurnDelegateDecoder()])]
      ])
    ],
    [
      "Edition",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getEditionDecoder()])]])
    ],
    [
      "MasterEdition",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getMasterEditionDecoder()])]
      ])
    ],
    [
      "AddBlocker",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getAddBlockerDecoder()])]])
    ],
    [
      "ImmutableMetadata",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getImmutableMetadataDecoder()])]
      ])
    ],
    [
      "VerifiedCreators",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getVerifiedCreatorsDecoder()])]
      ])
    ],
    [
      "Autograph",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getAutographDecoder()])]])
    ]
  ]);
}
function getPluginCodec() {
  return web3_js.combineCodec(getPluginEncoder(), getPluginDecoder());
}
function plugin(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPlugin(kind, value) {
  return value.__kind === kind;
}
function getPluginAuthorityPairEncoder() {
  return web3_js.getStructEncoder([
    ["plugin", getPluginEncoder()],
    ["authority", web3_js.getOptionEncoder(getAuthorityEncoder())]
  ]);
}
function getPluginAuthorityPairDecoder() {
  return web3_js.getStructDecoder([
    ["plugin", getPluginDecoder()],
    ["authority", web3_js.getOptionDecoder(getAuthorityDecoder())]
  ]);
}
function getPluginAuthorityPairCodec() {
  return web3_js.combineCodec(
    getPluginAuthorityPairEncoder(),
    getPluginAuthorityPairDecoder()
  );
}
var PluginType = /* @__PURE__ */ ((PluginType3) => {
  PluginType3[PluginType3["Royalties"] = 0] = "Royalties";
  PluginType3[PluginType3["FreezeDelegate"] = 1] = "FreezeDelegate";
  PluginType3[PluginType3["BurnDelegate"] = 2] = "BurnDelegate";
  PluginType3[PluginType3["TransferDelegate"] = 3] = "TransferDelegate";
  PluginType3[PluginType3["UpdateDelegate"] = 4] = "UpdateDelegate";
  PluginType3[PluginType3["PermanentFreezeDelegate"] = 5] = "PermanentFreezeDelegate";
  PluginType3[PluginType3["Attributes"] = 6] = "Attributes";
  PluginType3[PluginType3["PermanentTransferDelegate"] = 7] = "PermanentTransferDelegate";
  PluginType3[PluginType3["PermanentBurnDelegate"] = 8] = "PermanentBurnDelegate";
  PluginType3[PluginType3["Edition"] = 9] = "Edition";
  PluginType3[PluginType3["MasterEdition"] = 10] = "MasterEdition";
  PluginType3[PluginType3["AddBlocker"] = 11] = "AddBlocker";
  PluginType3[PluginType3["ImmutableMetadata"] = 12] = "ImmutableMetadata";
  PluginType3[PluginType3["VerifiedCreators"] = 13] = "VerifiedCreators";
  PluginType3[PluginType3["Autograph"] = 14] = "Autograph";
  return PluginType3;
})(PluginType || {});
function getPluginTypeEncoder() {
  return web3_js.getEnumEncoder(PluginType);
}
function getPluginTypeDecoder() {
  return web3_js.getEnumDecoder(PluginType);
}
function getPluginTypeCodec() {
  return web3_js.combineCodec(getPluginTypeEncoder(), getPluginTypeDecoder());
}
function getRegistryRecordEncoder() {
  return web3_js.getStructEncoder([
    ["pluginType", getPluginTypeEncoder()],
    ["authority", getAuthorityEncoder()],
    ["offset", web3_js.getU64Encoder()]
  ]);
}
function getRegistryRecordDecoder() {
  return web3_js.getStructDecoder([
    ["pluginType", getPluginTypeDecoder()],
    ["authority", getAuthorityDecoder()],
    ["offset", web3_js.getU64Decoder()]
  ]);
}
function getRegistryRecordCodec() {
  return web3_js.combineCodec(getRegistryRecordEncoder(), getRegistryRecordDecoder());
}
function getRoyaltiesEncoder() {
  return web3_js.getStructEncoder([
    ["basisPoints", web3_js.getU16Encoder()],
    ["creators", web3_js.getArrayEncoder(getCreatorEncoder())],
    ["ruleSet", getRuleSetEncoder()]
  ]);
}
function getRoyaltiesDecoder() {
  return web3_js.getStructDecoder([
    ["basisPoints", web3_js.getU16Decoder()],
    ["creators", web3_js.getArrayDecoder(getCreatorDecoder())],
    ["ruleSet", getRuleSetDecoder()]
  ]);
}
function getRoyaltiesCodec() {
  return web3_js.combineCodec(getRoyaltiesEncoder(), getRoyaltiesDecoder());
}
function getRuleSetEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["None", web3_js.getUnitEncoder()],
    [
      "ProgramAllowList",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([web3_js.getArrayEncoder(web3_js.getAddressEncoder())])]
      ])
    ],
    [
      "ProgramDenyList",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([web3_js.getArrayEncoder(web3_js.getAddressEncoder())])]
      ])
    ]
  ]);
}
function getRuleSetDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["None", web3_js.getUnitDecoder()],
    [
      "ProgramAllowList",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([web3_js.getArrayDecoder(web3_js.getAddressDecoder())])]
      ])
    ],
    [
      "ProgramDenyList",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([web3_js.getArrayDecoder(web3_js.getAddressDecoder())])]
      ])
    ]
  ]);
}
function getRuleSetCodec() {
  return web3_js.combineCodec(getRuleSetEncoder(), getRuleSetDecoder());
}
function ruleSet(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isRuleSet(kind, value) {
  return value.__kind === kind;
}
function getSeedEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["Collection", web3_js.getUnitEncoder()],
    ["Owner", web3_js.getUnitEncoder()],
    ["Recipient", web3_js.getUnitEncoder()],
    ["Asset", web3_js.getUnitEncoder()],
    [
      "Address",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getAddressEncoder()])]])
    ],
    [
      "Bytes",
      web3_js.getStructEncoder([
        [
          "fields",
          web3_js.getTupleEncoder([
            web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder())
          ])
        ]
      ])
    ]
  ]);
}
function getSeedDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["Collection", web3_js.getUnitDecoder()],
    ["Owner", web3_js.getUnitDecoder()],
    ["Recipient", web3_js.getUnitDecoder()],
    ["Asset", web3_js.getUnitDecoder()],
    [
      "Address",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getAddressDecoder()])]])
    ],
    [
      "Bytes",
      web3_js.getStructDecoder([
        [
          "fields",
          web3_js.getTupleDecoder([
            web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder())
          ])
        ]
      ])
    ]
  ]);
}
function getSeedCodec() {
  return web3_js.combineCodec(getSeedEncoder(), getSeedDecoder());
}
function seed(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isSeed(kind, value) {
  return value.__kind === kind;
}
function getTransferDelegateEncoder() {
  return web3_js.getStructEncoder([]);
}
function getTransferDelegateDecoder() {
  return web3_js.getStructDecoder([]);
}
function getTransferDelegateCodec() {
  return web3_js.combineCodec(
    getTransferDelegateEncoder(),
    getTransferDelegateDecoder()
  );
}
function getUpdateAuthorityEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["None", web3_js.getUnitEncoder()],
    [
      "Address",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getAddressEncoder()])]])
    ],
    [
      "Collection",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getAddressEncoder()])]])
    ]
  ]);
}
function getUpdateAuthorityDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["None", web3_js.getUnitDecoder()],
    [
      "Address",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getAddressDecoder()])]])
    ],
    [
      "Collection",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getAddressDecoder()])]])
    ]
  ]);
}
function getUpdateAuthorityCodec() {
  return web3_js.combineCodec(getUpdateAuthorityEncoder(), getUpdateAuthorityDecoder());
}
function updateAuthority(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isUpdateAuthority(kind, value) {
  return value.__kind === kind;
}
function getUpdateDelegateEncoder() {
  return web3_js.getStructEncoder([
    ["additionalDelegates", web3_js.getArrayEncoder(web3_js.getAddressEncoder())]
  ]);
}
function getUpdateDelegateDecoder() {
  return web3_js.getStructDecoder([
    ["additionalDelegates", web3_js.getArrayDecoder(web3_js.getAddressDecoder())]
  ]);
}
function getUpdateDelegateCodec() {
  return web3_js.combineCodec(getUpdateDelegateEncoder(), getUpdateDelegateDecoder());
}
var ValidationResult = /* @__PURE__ */ ((ValidationResult2) => {
  ValidationResult2[ValidationResult2["Approved"] = 0] = "Approved";
  ValidationResult2[ValidationResult2["Rejected"] = 1] = "Rejected";
  ValidationResult2[ValidationResult2["Pass"] = 2] = "Pass";
  ValidationResult2[ValidationResult2["ForceApproved"] = 3] = "ForceApproved";
  return ValidationResult2;
})(ValidationResult || {});
function getValidationResultEncoder() {
  return web3_js.getEnumEncoder(ValidationResult);
}
function getValidationResultDecoder() {
  return web3_js.getEnumDecoder(ValidationResult);
}
function getValidationResultCodec() {
  return web3_js.combineCodec(
    getValidationResultEncoder(),
    getValidationResultDecoder()
  );
}
function getValidationResultsOffsetEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["NoOffset", web3_js.getUnitEncoder()],
    ["Anchor", web3_js.getUnitEncoder()],
    [
      "Custom",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([web3_js.getU64Encoder()])]])
    ]
  ]);
}
function getValidationResultsOffsetDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["NoOffset", web3_js.getUnitDecoder()],
    ["Anchor", web3_js.getUnitDecoder()],
    [
      "Custom",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([web3_js.getU64Decoder()])]])
    ]
  ]);
}
function getValidationResultsOffsetCodec() {
  return web3_js.combineCodec(
    getValidationResultsOffsetEncoder(),
    getValidationResultsOffsetDecoder()
  );
}
function validationResultsOffset(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isValidationResultsOffset(kind, value) {
  return value.__kind === kind;
}
function getVerifiedCreatorsEncoder() {
  return web3_js.getStructEncoder([
    ["signatures", web3_js.getArrayEncoder(getVerifiedCreatorsSignatureEncoder())]
  ]);
}
function getVerifiedCreatorsDecoder() {
  return web3_js.getStructDecoder([
    ["signatures", web3_js.getArrayDecoder(getVerifiedCreatorsSignatureDecoder())]
  ]);
}
function getVerifiedCreatorsCodec() {
  return web3_js.combineCodec(
    getVerifiedCreatorsEncoder(),
    getVerifiedCreatorsDecoder()
  );
}
function getVerifiedCreatorsSignatureEncoder() {
  return web3_js.getStructEncoder([
    ["address", web3_js.getAddressEncoder()],
    ["verified", web3_js.getBooleanEncoder()]
  ]);
}
function getVerifiedCreatorsSignatureDecoder() {
  return web3_js.getStructDecoder([
    ["address", web3_js.getAddressDecoder()],
    ["verified", web3_js.getBooleanDecoder()]
  ]);
}
function getVerifiedCreatorsSignatureCodec() {
  return web3_js.combineCodec(
    getVerifiedCreatorsSignatureEncoder(),
    getVerifiedCreatorsSignatureDecoder()
  );
}

// src/generated/accounts/assetV1.ts
function getAssetV1Encoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["owner", web3_js.getAddressEncoder()],
    ["updateAuthority", getUpdateAuthorityEncoder()],
    ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["seq", web3_js.getOptionEncoder(web3_js.getU64Encoder())]
  ]);
}
function getAssetV1Decoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["owner", web3_js.getAddressDecoder()],
    ["updateAuthority", getUpdateAuthorityDecoder()],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["seq", web3_js.getOptionDecoder(web3_js.getU64Decoder())]
  ]);
}
function getAssetV1Codec() {
  return web3_js.combineCodec(getAssetV1Encoder(), getAssetV1Decoder());
}
function decodeAssetV1(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getAssetV1Decoder()
  );
}
async function fetchAssetV1(rpc, address, config) {
  const maybeAccount = await fetchMaybeAssetV1(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeAssetV1(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeAssetV1(maybeAccount);
}
async function fetchAllAssetV1(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeAssetV1(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeAssetV1(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeAssetV1(maybeAccount));
}
function getCollectionV1Encoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["updateAuthority", web3_js.getAddressEncoder()],
    ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
    ["numMinted", web3_js.getU32Encoder()],
    ["currentSize", web3_js.getU32Encoder()]
  ]);
}
function getCollectionV1Decoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["updateAuthority", web3_js.getAddressDecoder()],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["numMinted", web3_js.getU32Decoder()],
    ["currentSize", web3_js.getU32Decoder()]
  ]);
}
function getCollectionV1Codec() {
  return web3_js.combineCodec(getCollectionV1Encoder(), getCollectionV1Decoder());
}
function decodeCollectionV1(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getCollectionV1Decoder()
  );
}
async function fetchCollectionV1(rpc, address, config) {
  const maybeAccount = await fetchMaybeCollectionV1(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeCollectionV1(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeCollectionV1(maybeAccount);
}
async function fetchAllCollectionV1(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeCollectionV1(rpc, addresses, config);
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeCollectionV1(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeCollectionV1(maybeAccount));
}
function getHashedAssetV1Encoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["hash", web3_js.fixEncoderSize(web3_js.getBytesEncoder(), 32)]
  ]);
}
function getHashedAssetV1Decoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["hash", web3_js.fixDecoderSize(web3_js.getBytesDecoder(), 32)]
  ]);
}
function getHashedAssetV1Codec() {
  return web3_js.combineCodec(getHashedAssetV1Encoder(), getHashedAssetV1Decoder());
}
function decodeHashedAssetV1(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getHashedAssetV1Decoder()
  );
}
async function fetchHashedAssetV1(rpc, address, config) {
  const maybeAccount = await fetchMaybeHashedAssetV1(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeHashedAssetV1(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodeHashedAssetV1(maybeAccount);
}
async function fetchAllHashedAssetV1(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeHashedAssetV1(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeHashedAssetV1(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeHashedAssetV1(maybeAccount));
}
function getHashedAssetV1Size() {
  return 33;
}
function getPluginHeaderV1Encoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["pluginRegistryOffset", web3_js.getU64Encoder()]
  ]);
}
function getPluginHeaderV1Decoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["pluginRegistryOffset", web3_js.getU64Decoder()]
  ]);
}
function getPluginHeaderV1Codec() {
  return web3_js.combineCodec(getPluginHeaderV1Encoder(), getPluginHeaderV1Decoder());
}
function decodePluginHeaderV1(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getPluginHeaderV1Decoder()
  );
}
async function fetchPluginHeaderV1(rpc, address, config) {
  const maybeAccount = await fetchMaybePluginHeaderV1(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybePluginHeaderV1(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodePluginHeaderV1(maybeAccount);
}
async function fetchAllPluginHeaderV1(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybePluginHeaderV1(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybePluginHeaderV1(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodePluginHeaderV1(maybeAccount)
  );
}
function getPluginHeaderV1Size() {
  return 9;
}
function getPluginRegistryV1Encoder() {
  return web3_js.getStructEncoder([
    ["key", getKeyEncoder()],
    ["registry", web3_js.getArrayEncoder(getRegistryRecordEncoder())],
    ["externalRegistry", web3_js.getArrayEncoder(getExternalRegistryRecordEncoder())]
  ]);
}
function getPluginRegistryV1Decoder() {
  return web3_js.getStructDecoder([
    ["key", getKeyDecoder()],
    ["registry", web3_js.getArrayDecoder(getRegistryRecordDecoder())],
    ["externalRegistry", web3_js.getArrayDecoder(getExternalRegistryRecordDecoder())]
  ]);
}
function getPluginRegistryV1Codec() {
  return web3_js.combineCodec(
    getPluginRegistryV1Encoder(),
    getPluginRegistryV1Decoder()
  );
}
function decodePluginRegistryV1(encodedAccount) {
  return web3_js.decodeAccount(
    encodedAccount,
    getPluginRegistryV1Decoder()
  );
}
async function fetchPluginRegistryV1(rpc, address, config) {
  const maybeAccount = await fetchMaybePluginRegistryV1(rpc, address, config);
  web3_js.assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybePluginRegistryV1(rpc, address, config) {
  const maybeAccount = await web3_js.fetchEncodedAccount(rpc, address, config);
  return decodePluginRegistryV1(maybeAccount);
}
async function fetchAllPluginRegistryV1(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybePluginRegistryV1(
    rpc,
    addresses,
    config
  );
  web3_js.assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybePluginRegistryV1(rpc, addresses, config) {
  const maybeAccounts = await web3_js.fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map(
    (maybeAccount) => decodePluginRegistryV1(maybeAccount)
  );
}
var MPL_CORE_PROGRAM_PROGRAM_ADDRESS = "CoREENxT6tW1HoK8ypY1SxRMZTcVPm7R94rH4PZNhX7d";
var MplCoreProgramAccount = /* @__PURE__ */ ((MplCoreProgramAccount2) => {
  MplCoreProgramAccount2[MplCoreProgramAccount2["PluginHeaderV1"] = 0] = "PluginHeaderV1";
  MplCoreProgramAccount2[MplCoreProgramAccount2["PluginRegistryV1"] = 1] = "PluginRegistryV1";
  MplCoreProgramAccount2[MplCoreProgramAccount2["AssetV1"] = 2] = "AssetV1";
  MplCoreProgramAccount2[MplCoreProgramAccount2["CollectionV1"] = 3] = "CollectionV1";
  MplCoreProgramAccount2[MplCoreProgramAccount2["HashedAssetV1"] = 4] = "HashedAssetV1";
  return MplCoreProgramAccount2;
})(MplCoreProgramAccount || {});
var MplCoreProgramInstruction = /* @__PURE__ */ ((MplCoreProgramInstruction2) => {
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["CreateV1"] = 0] = "CreateV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["CreateCollectionV1"] = 1] = "CreateCollectionV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["AddPluginV1"] = 2] = "AddPluginV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["AddCollectionPluginV1"] = 3] = "AddCollectionPluginV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["RemovePluginV1"] = 4] = "RemovePluginV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["RemoveCollectionPluginV1"] = 5] = "RemoveCollectionPluginV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["UpdatePluginV1"] = 6] = "UpdatePluginV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["UpdateCollectionPluginV1"] = 7] = "UpdateCollectionPluginV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["ApprovePluginAuthorityV1"] = 8] = "ApprovePluginAuthorityV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["ApproveCollectionPluginAuthorityV1"] = 9] = "ApproveCollectionPluginAuthorityV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["RevokePluginAuthorityV1"] = 10] = "RevokePluginAuthorityV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["RevokeCollectionPluginAuthorityV1"] = 11] = "RevokeCollectionPluginAuthorityV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["BurnV1"] = 12] = "BurnV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["BurnCollectionV1"] = 13] = "BurnCollectionV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["TransferV1"] = 14] = "TransferV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["UpdateV1"] = 15] = "UpdateV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["UpdateCollectionV1"] = 16] = "UpdateCollectionV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["CompressV1"] = 17] = "CompressV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["DecompressV1"] = 18] = "DecompressV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["Collect"] = 19] = "Collect";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["CreateV2"] = 20] = "CreateV2";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["CreateCollectionV2"] = 21] = "CreateCollectionV2";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["AddExternalPluginAdapterV1"] = 22] = "AddExternalPluginAdapterV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["AddCollectionExternalPluginAdapterV1"] = 23] = "AddCollectionExternalPluginAdapterV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["RemoveExternalPluginAdapterV1"] = 24] = "RemoveExternalPluginAdapterV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["RemoveCollectionExternalPluginAdapterV1"] = 25] = "RemoveCollectionExternalPluginAdapterV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["UpdateExternalPluginAdapterV1"] = 26] = "UpdateExternalPluginAdapterV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["UpdateCollectionExternalPluginAdapterV1"] = 27] = "UpdateCollectionExternalPluginAdapterV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["WriteExternalPluginAdapterDataV1"] = 28] = "WriteExternalPluginAdapterDataV1";
  MplCoreProgramInstruction2[MplCoreProgramInstruction2["WriteCollectionExternalPluginAdapterDataV1"] = 29] = "WriteCollectionExternalPluginAdapterDataV1";
  return MplCoreProgramInstruction2;
})(MplCoreProgramInstruction || {});
function identifyMplCoreProgramInstruction(instruction) {
  const data = "data" in instruction ? instruction.data : instruction;
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(0), 0)) {
    return 0 /* CreateV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(1), 0)) {
    return 1 /* CreateCollectionV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(2), 0)) {
    return 2 /* AddPluginV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(3), 0)) {
    return 3 /* AddCollectionPluginV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(4), 0)) {
    return 4 /* RemovePluginV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(5), 0)) {
    return 5 /* RemoveCollectionPluginV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(6), 0)) {
    return 6 /* UpdatePluginV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(7), 0)) {
    return 7 /* UpdateCollectionPluginV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(8), 0)) {
    return 8 /* ApprovePluginAuthorityV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(9), 0)) {
    return 9 /* ApproveCollectionPluginAuthorityV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(10), 0)) {
    return 10 /* RevokePluginAuthorityV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(11), 0)) {
    return 11 /* RevokeCollectionPluginAuthorityV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(12), 0)) {
    return 12 /* BurnV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(13), 0)) {
    return 13 /* BurnCollectionV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(14), 0)) {
    return 14 /* TransferV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(15), 0)) {
    return 15 /* UpdateV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(16), 0)) {
    return 16 /* UpdateCollectionV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(17), 0)) {
    return 17 /* CompressV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(18), 0)) {
    return 18 /* DecompressV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(19), 0)) {
    return 19 /* Collect */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(20), 0)) {
    return 20 /* CreateV2 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(21), 0)) {
    return 21 /* CreateCollectionV2 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(22), 0)) {
    return 22 /* AddExternalPluginAdapterV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(23), 0)) {
    return 23 /* AddCollectionExternalPluginAdapterV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(24), 0)) {
    return 24 /* RemoveExternalPluginAdapterV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(25), 0)) {
    return 25 /* RemoveCollectionExternalPluginAdapterV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(26), 0)) {
    return 26 /* UpdateExternalPluginAdapterV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(27), 0)) {
    return 27 /* UpdateCollectionExternalPluginAdapterV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(28), 0)) {
    return 28 /* WriteExternalPluginAdapterDataV1 */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(29), 0)) {
    return 29 /* WriteCollectionExternalPluginAdapterDataV1 */;
  }
  throw new Error(
    "The provided instruction could not be identified as a mplCoreProgram instruction."
  );
}

// src/generated/errors/mplCoreProgram.ts
var MPL_CORE_PROGRAM_ERROR__INVALID_SYSTEM_PROGRAM = 0;
var MPL_CORE_PROGRAM_ERROR__DESERIALIZATION_ERROR = 1;
var MPL_CORE_PROGRAM_ERROR__SERIALIZATION_ERROR = 2;
var MPL_CORE_PROGRAM_ERROR__PLUGINS_NOT_INITIALIZED = 3;
var MPL_CORE_PROGRAM_ERROR__PLUGIN_NOT_FOUND = 4;
var MPL_CORE_PROGRAM_ERROR__NUMERICAL_OVERFLOW = 5;
var MPL_CORE_PROGRAM_ERROR__INCORRECT_ACCOUNT = 6;
var MPL_CORE_PROGRAM_ERROR__INCORRECT_ASSET_HASH = 7;
var MPL_CORE_PROGRAM_ERROR__INVALID_PLUGIN = 8;
var MPL_CORE_PROGRAM_ERROR__INVALID_AUTHORITY = 9;
var MPL_CORE_PROGRAM_ERROR__ASSET_IS_FROZEN = 10;
var MPL_CORE_PROGRAM_ERROR__MISSING_COMPRESSION_PROOF = 11;
var MPL_CORE_PROGRAM_ERROR__CANNOT_MIGRATE_MASTER_WITH_SUPPLY = 12;
var MPL_CORE_PROGRAM_ERROR__CANNOT_MIGRATE_PRINTS = 13;
var MPL_CORE_PROGRAM_ERROR__CANNOT_BURN_COLLECTION = 14;
var MPL_CORE_PROGRAM_ERROR__PLUGIN_ALREADY_EXISTS = 15;
var MPL_CORE_PROGRAM_ERROR__NUMERICAL_OVERFLOW_ERROR = 16;
var MPL_CORE_PROGRAM_ERROR__ALREADY_COMPRESSED = 17;
var MPL_CORE_PROGRAM_ERROR__ALREADY_DECOMPRESSED = 18;
var MPL_CORE_PROGRAM_ERROR__INVALID_COLLECTION = 19;
var MPL_CORE_PROGRAM_ERROR__MISSING_UPDATE_AUTHORITY = 20;
var MPL_CORE_PROGRAM_ERROR__MISSING_NEW_OWNER = 21;
var MPL_CORE_PROGRAM_ERROR__MISSING_SYSTEM_PROGRAM = 22;
var MPL_CORE_PROGRAM_ERROR__NOT_AVAILABLE = 23;
var MPL_CORE_PROGRAM_ERROR__INVALID_ASSET = 24;
var MPL_CORE_PROGRAM_ERROR__MISSING_COLLECTION = 25;
var MPL_CORE_PROGRAM_ERROR__NO_APPROVALS = 26;
var MPL_CORE_PROGRAM_ERROR__CANNOT_REDELEGATE = 27;
var MPL_CORE_PROGRAM_ERROR__INVALID_PLUGIN_SETTING = 28;
var MPL_CORE_PROGRAM_ERROR__CONFLICTING_AUTHORITY = 29;
var MPL_CORE_PROGRAM_ERROR__INVALID_LOG_WRAPPER_PROGRAM = 30;
var MPL_CORE_PROGRAM_ERROR__EXTERNAL_PLUGIN_ADAPTER_NOT_FOUND = 31;
var MPL_CORE_PROGRAM_ERROR__EXTERNAL_PLUGIN_ADAPTER_ALREADY_EXISTS = 32;
var MPL_CORE_PROGRAM_ERROR__MISSING_ASSET = 33;
var MPL_CORE_PROGRAM_ERROR__MISSING_EXTERNAL_PLUGIN_ADAPTER_ACCOUNT = 34;
var MPL_CORE_PROGRAM_ERROR__ORACLE_CAN_REJECT_ONLY = 35;
var MPL_CORE_PROGRAM_ERROR__REQUIRES_LIFECYCLE_CHECK = 36;
var MPL_CORE_PROGRAM_ERROR__DUPLICATE_LIFECYCLE_CHECKS = 37;
var MPL_CORE_PROGRAM_ERROR__INVALID_ORACLE_ACCOUNT_DATA = 38;
var MPL_CORE_PROGRAM_ERROR__UNINITIALIZED_ORACLE_ACCOUNT = 39;
var MPL_CORE_PROGRAM_ERROR__MISSING_SIGNER = 40;
var MPL_CORE_PROGRAM_ERROR__INVALID_PLUGIN_OPERATION = 41;
var mplCoreProgramErrorMessages;
if (process.env.NODE_ENV !== "production") {
  mplCoreProgramErrorMessages = {
    [MPL_CORE_PROGRAM_ERROR__ALREADY_COMPRESSED]: `Already compressed account`,
    [MPL_CORE_PROGRAM_ERROR__ALREADY_DECOMPRESSED]: `Already decompressed account`,
    [MPL_CORE_PROGRAM_ERROR__ASSET_IS_FROZEN]: `Cannot transfer a frozen asset`,
    [MPL_CORE_PROGRAM_ERROR__CANNOT_BURN_COLLECTION]: `Cannot burn a collection NFT`,
    [MPL_CORE_PROGRAM_ERROR__CANNOT_MIGRATE_MASTER_WITH_SUPPLY]: `Cannot migrate a master edition used for prints`,
    [MPL_CORE_PROGRAM_ERROR__CANNOT_MIGRATE_PRINTS]: `Cannot migrate a print edition`,
    [MPL_CORE_PROGRAM_ERROR__CANNOT_REDELEGATE]: `Plugin Manager cannot redelegate a delegated plugin without revoking first`,
    [MPL_CORE_PROGRAM_ERROR__CONFLICTING_AUTHORITY]: `Cannot specify both an update authority and collection on an asset`,
    [MPL_CORE_PROGRAM_ERROR__DESERIALIZATION_ERROR]: `Error deserializing account`,
    [MPL_CORE_PROGRAM_ERROR__DUPLICATE_LIFECYCLE_CHECKS]: `Duplicate lifecycle checks were provided for external plugin adapter `,
    [MPL_CORE_PROGRAM_ERROR__EXTERNAL_PLUGIN_ADAPTER_ALREADY_EXISTS]: `External PluginExternalPluginAdapter already exists`,
    [MPL_CORE_PROGRAM_ERROR__EXTERNAL_PLUGIN_ADAPTER_NOT_FOUND]: `External PluginExternalPluginAdapter not found`,
    [MPL_CORE_PROGRAM_ERROR__INCORRECT_ACCOUNT]: `Incorrect account`,
    [MPL_CORE_PROGRAM_ERROR__INCORRECT_ASSET_HASH]: `Incorrect asset hash`,
    [MPL_CORE_PROGRAM_ERROR__INVALID_ASSET]: `Invalid Asset passed in`,
    [MPL_CORE_PROGRAM_ERROR__INVALID_AUTHORITY]: `Invalid Authority`,
    [MPL_CORE_PROGRAM_ERROR__INVALID_COLLECTION]: `Invalid Collection passed in`,
    [MPL_CORE_PROGRAM_ERROR__INVALID_LOG_WRAPPER_PROGRAM]: `Invalid Log Wrapper Program`,
    [MPL_CORE_PROGRAM_ERROR__INVALID_ORACLE_ACCOUNT_DATA]: `Could not read from oracle account`,
    [MPL_CORE_PROGRAM_ERROR__INVALID_PLUGIN]: `Invalid Plugin`,
    [MPL_CORE_PROGRAM_ERROR__INVALID_PLUGIN_OPERATION]: `Invalid plugin operation`,
    [MPL_CORE_PROGRAM_ERROR__INVALID_PLUGIN_SETTING]: `Invalid setting for plugin`,
    [MPL_CORE_PROGRAM_ERROR__INVALID_SYSTEM_PROGRAM]: `Invalid System Program`,
    [MPL_CORE_PROGRAM_ERROR__MISSING_ASSET]: `Missing asset needed for extra account PDA derivation`,
    [MPL_CORE_PROGRAM_ERROR__MISSING_COLLECTION]: `Missing collection`,
    [MPL_CORE_PROGRAM_ERROR__MISSING_COMPRESSION_PROOF]: `Missing compression proof`,
    [MPL_CORE_PROGRAM_ERROR__MISSING_EXTERNAL_PLUGIN_ADAPTER_ACCOUNT]: `Missing account needed for external plugin adapter`,
    [MPL_CORE_PROGRAM_ERROR__MISSING_NEW_OWNER]: `Missing new owner`,
    [MPL_CORE_PROGRAM_ERROR__MISSING_SIGNER]: `Missing required signer for operation`,
    [MPL_CORE_PROGRAM_ERROR__MISSING_SYSTEM_PROGRAM]: `Missing system program`,
    [MPL_CORE_PROGRAM_ERROR__MISSING_UPDATE_AUTHORITY]: `Missing update authority`,
    [MPL_CORE_PROGRAM_ERROR__NO_APPROVALS]: `Neither the asset or any plugins have approved this operation`,
    [MPL_CORE_PROGRAM_ERROR__NOT_AVAILABLE]: `Feature not available`,
    [MPL_CORE_PROGRAM_ERROR__NUMERICAL_OVERFLOW]: `Numerical Overflow`,
    [MPL_CORE_PROGRAM_ERROR__NUMERICAL_OVERFLOW_ERROR]: `Numerical overflow`,
    [MPL_CORE_PROGRAM_ERROR__ORACLE_CAN_REJECT_ONLY]: `Oracle external plugin adapter can only be configured to reject`,
    [MPL_CORE_PROGRAM_ERROR__PLUGIN_ALREADY_EXISTS]: `Plugin already exists`,
    [MPL_CORE_PROGRAM_ERROR__PLUGIN_NOT_FOUND]: `Plugin not found`,
    [MPL_CORE_PROGRAM_ERROR__PLUGINS_NOT_INITIALIZED]: `Plugins not initialized`,
    [MPL_CORE_PROGRAM_ERROR__REQUIRES_LIFECYCLE_CHECK]: `External plugin adapter must have at least one lifecycle check`,
    [MPL_CORE_PROGRAM_ERROR__SERIALIZATION_ERROR]: `Error serializing account`,
    [MPL_CORE_PROGRAM_ERROR__UNINITIALIZED_ORACLE_ACCOUNT]: `Oracle account is uninitialized`
  };
}
function getMplCoreProgramErrorMessage(code) {
  if (process.env.NODE_ENV !== "production") {
    return mplCoreProgramErrorMessages[code];
  }
  return "Error message not available in production bundles.";
}
function isMplCoreProgramError(error, transactionMessage, code) {
  return web3_js.isProgramError(
    error,
    transactionMessage,
    MPL_CORE_PROGRAM_PROGRAM_ADDRESS,
    code
  );
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: web3_js.AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? web3_js.AccountRole.WRITABLE : web3_js.AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? web3_js.upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && web3_js.isTransactionSigner(value);
}

// src/generated/instructions/addCollectionExternalPluginAdapterV1.ts
var ADD_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR = 23;
function getAddCollectionExternalPluginAdapterV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(
    ADD_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR
  );
}
function getAddCollectionExternalPluginAdapterV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["initInfo", getExternalPluginAdapterInitInfoEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: ADD_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR
    })
  );
}
function getAddCollectionExternalPluginAdapterV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["initInfo", getExternalPluginAdapterInitInfoDecoder()]
  ]);
}
function getAddCollectionExternalPluginAdapterV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getAddCollectionExternalPluginAdapterV1InstructionDataEncoder(),
    getAddCollectionExternalPluginAdapterV1InstructionDataDecoder()
  );
}
function getAddCollectionExternalPluginAdapterV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getAddCollectionExternalPluginAdapterV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseAddCollectionExternalPluginAdapterV1Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getAddCollectionExternalPluginAdapterV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var ADD_COLLECTION_PLUGIN_V1_DISCRIMINATOR = 3;
function getAddCollectionPluginV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(ADD_COLLECTION_PLUGIN_V1_DISCRIMINATOR);
}
function getAddCollectionPluginV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["plugin", getPluginEncoder()],
      ["initAuthority", web3_js.getOptionEncoder(getAuthorityEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: ADD_COLLECTION_PLUGIN_V1_DISCRIMINATOR
    })
  );
}
function getAddCollectionPluginV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["plugin", getPluginDecoder()],
    ["initAuthority", web3_js.getOptionDecoder(getAuthorityDecoder())]
  ]);
}
function getAddCollectionPluginV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getAddCollectionPluginV1InstructionDataEncoder(),
    getAddCollectionPluginV1InstructionDataDecoder()
  );
}
function getAddCollectionPluginV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getAddCollectionPluginV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseAddCollectionPluginV1Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getAddCollectionPluginV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var ADD_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR = 22;
function getAddExternalPluginAdapterV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(ADD_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR);
}
function getAddExternalPluginAdapterV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["initInfo", getExternalPluginAdapterInitInfoEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: ADD_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR
    })
  );
}
function getAddExternalPluginAdapterV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["initInfo", getExternalPluginAdapterInitInfoDecoder()]
  ]);
}
function getAddExternalPluginAdapterV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getAddExternalPluginAdapterV1InstructionDataEncoder(),
    getAddExternalPluginAdapterV1InstructionDataDecoder()
  );
}
function getAddExternalPluginAdapterV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getAddExternalPluginAdapterV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseAddExternalPluginAdapterV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getAddExternalPluginAdapterV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var ADD_PLUGIN_V1_DISCRIMINATOR = 2;
function getAddPluginV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(ADD_PLUGIN_V1_DISCRIMINATOR);
}
function getAddPluginV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["plugin", getPluginEncoder()],
      ["initAuthority", web3_js.getOptionEncoder(getAuthorityEncoder())]
    ]),
    (value) => ({ ...value, discriminator: ADD_PLUGIN_V1_DISCRIMINATOR })
  );
}
function getAddPluginV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["plugin", getPluginDecoder()],
    ["initAuthority", web3_js.getOptionDecoder(getAuthorityDecoder())]
  ]);
}
function getAddPluginV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getAddPluginV1InstructionDataEncoder(),
    getAddPluginV1InstructionDataDecoder()
  );
}
function getAddPluginV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getAddPluginV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseAddPluginV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getAddPluginV1InstructionDataDecoder().decode(instruction.data)
  };
}
var APPROVE_COLLECTION_PLUGIN_AUTHORITY_V1_DISCRIMINATOR = 9;
function getApproveCollectionPluginAuthorityV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(
    APPROVE_COLLECTION_PLUGIN_AUTHORITY_V1_DISCRIMINATOR
  );
}
function getApproveCollectionPluginAuthorityV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["pluginType", getPluginTypeEncoder()],
      ["newAuthority", getAuthorityEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: APPROVE_COLLECTION_PLUGIN_AUTHORITY_V1_DISCRIMINATOR
    })
  );
}
function getApproveCollectionPluginAuthorityV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["pluginType", getPluginTypeDecoder()],
    ["newAuthority", getAuthorityDecoder()]
  ]);
}
function getApproveCollectionPluginAuthorityV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getApproveCollectionPluginAuthorityV1InstructionDataEncoder(),
    getApproveCollectionPluginAuthorityV1InstructionDataDecoder()
  );
}
function getApproveCollectionPluginAuthorityV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getApproveCollectionPluginAuthorityV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseApproveCollectionPluginAuthorityV1Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getApproveCollectionPluginAuthorityV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var APPROVE_PLUGIN_AUTHORITY_V1_DISCRIMINATOR = 8;
function getApprovePluginAuthorityV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(APPROVE_PLUGIN_AUTHORITY_V1_DISCRIMINATOR);
}
function getApprovePluginAuthorityV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["pluginType", getPluginTypeEncoder()],
      ["newAuthority", getAuthorityEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: APPROVE_PLUGIN_AUTHORITY_V1_DISCRIMINATOR
    })
  );
}
function getApprovePluginAuthorityV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["pluginType", getPluginTypeDecoder()],
    ["newAuthority", getAuthorityDecoder()]
  ]);
}
function getApprovePluginAuthorityV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getApprovePluginAuthorityV1InstructionDataEncoder(),
    getApprovePluginAuthorityV1InstructionDataDecoder()
  );
}
function getApprovePluginAuthorityV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getApprovePluginAuthorityV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseApprovePluginAuthorityV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getApprovePluginAuthorityV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var BURN_COLLECTION_V1_DISCRIMINATOR = 13;
function getBurnCollectionV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(BURN_COLLECTION_V1_DISCRIMINATOR);
}
function getBurnCollectionV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["compressionProof", web3_js.getOptionEncoder(getCompressionProofEncoder())]
    ]),
    (value) => ({ ...value, discriminator: BURN_COLLECTION_V1_DISCRIMINATOR })
  );
}
function getBurnCollectionV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["compressionProof", web3_js.getOptionDecoder(getCompressionProofDecoder())]
  ]);
}
function getBurnCollectionV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getBurnCollectionV1InstructionDataEncoder(),
    getBurnCollectionV1InstructionDataDecoder()
  );
}
function getBurnCollectionV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: true },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getBurnCollectionV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBurnCollectionV1Instruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getBurnCollectionV1InstructionDataDecoder().decode(instruction.data)
  };
}
var BURN_V1_DISCRIMINATOR = 12;
function getBurnV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(BURN_V1_DISCRIMINATOR);
}
function getBurnV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["compressionProof", web3_js.getOptionEncoder(getCompressionProofEncoder())]
    ]),
    (value) => ({ ...value, discriminator: BURN_V1_DISCRIMINATOR })
  );
}
function getBurnV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["compressionProof", web3_js.getOptionDecoder(getCompressionProofDecoder())]
  ]);
}
function getBurnV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getBurnV1InstructionDataEncoder(),
    getBurnV1InstructionDataDecoder()
  );
}
function getBurnV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getBurnV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseBurnV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextOptionalAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getBurnV1InstructionDataDecoder().decode(instruction.data)
  };
}
var COLLECT_DISCRIMINATOR = 19;
function getCollectDiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(COLLECT_DISCRIMINATOR);
}
function getCollectInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: COLLECT_DISCRIMINATOR })
  );
}
function getCollectInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getCollectInstructionDataCodec() {
  return web3_js.combineCodec(
    getCollectInstructionDataEncoder(),
    getCollectInstructionDataDecoder()
  );
}
function getCollectInstruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    recipient1: { value: input.recipient1 ?? null, isWritable: true },
    recipient2: { value: input.recipient2 ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.recipient1),
      getAccountMeta(accounts.recipient2)
    ],
    programAddress,
    data: getCollectInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCollectInstruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      recipient1: getNextAccount(),
      recipient2: getNextAccount()
    },
    data: getCollectInstructionDataDecoder().decode(instruction.data)
  };
}
var COMPRESS_V1_DISCRIMINATOR = 17;
function getCompressV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(COMPRESS_V1_DISCRIMINATOR);
}
function getCompressV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: COMPRESS_V1_DISCRIMINATOR })
  );
}
function getCompressV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getCompressV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getCompressV1InstructionDataEncoder(),
    getCompressV1InstructionDataDecoder()
  );
}
function getCompressV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getCompressV1InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCompressV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getCompressV1InstructionDataDecoder().decode(instruction.data)
  };
}
var CREATE_COLLECTION_V1_DISCRIMINATOR = 1;
function getCreateCollectionV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(CREATE_COLLECTION_V1_DISCRIMINATOR);
}
function getCreateCollectionV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      [
        "plugins",
        web3_js.getOptionEncoder(web3_js.getArrayEncoder(getPluginAuthorityPairEncoder()))
      ]
    ]),
    (value) => ({ ...value, discriminator: CREATE_COLLECTION_V1_DISCRIMINATOR })
  );
}
function getCreateCollectionV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    [
      "plugins",
      web3_js.getOptionDecoder(web3_js.getArrayDecoder(getPluginAuthorityPairDecoder()))
    ]
  ]);
}
function getCreateCollectionV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateCollectionV1InstructionDataEncoder(),
    getCreateCollectionV1InstructionDataDecoder()
  );
}
function getCreateCollectionV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateCollectionV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateCollectionV1Instruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      updateAuthority: getNextOptionalAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCreateCollectionV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var CREATE_COLLECTION_V2_DISCRIMINATOR = 21;
function getCreateCollectionV2DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(CREATE_COLLECTION_V2_DISCRIMINATOR);
}
function getCreateCollectionV2InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      [
        "plugins",
        web3_js.getOptionEncoder(web3_js.getArrayEncoder(getPluginAuthorityPairEncoder()))
      ],
      [
        "externalPluginAdapters",
        web3_js.getOptionEncoder(
          web3_js.getArrayEncoder(getExternalPluginAdapterInitInfoEncoder())
        )
      ]
    ]),
    (value) => ({ ...value, discriminator: CREATE_COLLECTION_V2_DISCRIMINATOR })
  );
}
function getCreateCollectionV2InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    [
      "plugins",
      web3_js.getOptionDecoder(web3_js.getArrayDecoder(getPluginAuthorityPairDecoder()))
    ],
    [
      "externalPluginAdapters",
      web3_js.getOptionDecoder(
        web3_js.getArrayDecoder(getExternalPluginAdapterInitInfoDecoder())
      )
    ]
  ]);
}
function getCreateCollectionV2InstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateCollectionV2InstructionDataEncoder(),
    getCreateCollectionV2InstructionDataDecoder()
  );
}
function getCreateCollectionV2Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateCollectionV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateCollectionV2Instruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      updateAuthority: getNextOptionalAccount(),
      payer: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCreateCollectionV2InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var CREATE_V1_DISCRIMINATOR = 0;
function getCreateV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(CREATE_V1_DISCRIMINATOR);
}
function getCreateV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["dataState", getDataStateEncoder()],
      ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      [
        "plugins",
        web3_js.getOptionEncoder(web3_js.getArrayEncoder(getPluginAuthorityPairEncoder()))
      ]
    ]),
    (value) => ({ ...value, discriminator: CREATE_V1_DISCRIMINATOR })
  );
}
function getCreateV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["dataState", getDataStateDecoder()],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    [
      "plugins",
      web3_js.getOptionDecoder(web3_js.getArrayDecoder(getPluginAuthorityPairDecoder()))
    ]
  ]);
}
function getCreateV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateV1InstructionDataEncoder(),
    getCreateV1InstructionDataDecoder()
  );
}
function getCreateV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getCreateV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateV1Instruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      authority: getNextOptionalAccount(),
      payer: getNextAccount(),
      owner: getNextOptionalAccount(),
      updateAuthority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getCreateV1InstructionDataDecoder().decode(instruction.data)
  };
}
var CREATE_V2_DISCRIMINATOR = 20;
function getCreateV2DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(CREATE_V2_DISCRIMINATOR);
}
function getCreateV2InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["dataState", getDataStateEncoder()],
      ["name", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      ["uri", web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())],
      [
        "plugins",
        web3_js.getOptionEncoder(web3_js.getArrayEncoder(getPluginAuthorityPairEncoder()))
      ],
      [
        "externalPluginAdapters",
        web3_js.getOptionEncoder(
          web3_js.getArrayEncoder(getExternalPluginAdapterInitInfoEncoder())
        )
      ]
    ]),
    (value) => ({ ...value, discriminator: CREATE_V2_DISCRIMINATOR })
  );
}
function getCreateV2InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["dataState", getDataStateDecoder()],
    ["name", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    ["uri", web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder())],
    [
      "plugins",
      web3_js.getOptionDecoder(web3_js.getArrayDecoder(getPluginAuthorityPairDecoder()))
    ],
    [
      "externalPluginAdapters",
      web3_js.getOptionDecoder(
        web3_js.getArrayDecoder(getExternalPluginAdapterInitInfoDecoder())
      )
    ]
  ]);
}
function getCreateV2InstructionDataCodec() {
  return web3_js.combineCodec(
    getCreateV2InstructionDataEncoder(),
    getCreateV2InstructionDataDecoder()
  );
}
function getCreateV2Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    updateAuthority: {
      value: input.updateAuthority ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getCreateV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateV2Instruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      authority: getNextOptionalAccount(),
      payer: getNextAccount(),
      owner: getNextOptionalAccount(),
      updateAuthority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getCreateV2InstructionDataDecoder().decode(instruction.data)
  };
}
var DECOMPRESS_V1_DISCRIMINATOR = 18;
function getDecompressV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(DECOMPRESS_V1_DISCRIMINATOR);
}
function getDecompressV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["compressionProof", getCompressionProofEncoder()]
    ]),
    (value) => ({ ...value, discriminator: DECOMPRESS_V1_DISCRIMINATOR })
  );
}
function getDecompressV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["compressionProof", getCompressionProofDecoder()]
  ]);
}
function getDecompressV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getDecompressV1InstructionDataEncoder(),
    getDecompressV1InstructionDataDecoder()
  );
}
function getDecompressV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getDecompressV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDecompressV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getDecompressV1InstructionDataDecoder().decode(instruction.data)
  };
}
var REMOVE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR = 25;
function getRemoveCollectionExternalPluginAdapterV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(
    REMOVE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR
  );
}
function getRemoveCollectionExternalPluginAdapterV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["key", getExternalPluginAdapterKeyEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: REMOVE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR
    })
  );
}
function getRemoveCollectionExternalPluginAdapterV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["key", getExternalPluginAdapterKeyDecoder()]
  ]);
}
function getRemoveCollectionExternalPluginAdapterV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getRemoveCollectionExternalPluginAdapterV1InstructionDataEncoder(),
    getRemoveCollectionExternalPluginAdapterV1InstructionDataDecoder()
  );
}
function getRemoveCollectionExternalPluginAdapterV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getRemoveCollectionExternalPluginAdapterV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseRemoveCollectionExternalPluginAdapterV1Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getRemoveCollectionExternalPluginAdapterV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var REMOVE_COLLECTION_PLUGIN_V1_DISCRIMINATOR = 5;
function getRemoveCollectionPluginV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(REMOVE_COLLECTION_PLUGIN_V1_DISCRIMINATOR);
}
function getRemoveCollectionPluginV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["pluginType", getPluginTypeEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: REMOVE_COLLECTION_PLUGIN_V1_DISCRIMINATOR
    })
  );
}
function getRemoveCollectionPluginV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["pluginType", getPluginTypeDecoder()]
  ]);
}
function getRemoveCollectionPluginV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getRemoveCollectionPluginV1InstructionDataEncoder(),
    getRemoveCollectionPluginV1InstructionDataDecoder()
  );
}
function getRemoveCollectionPluginV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getRemoveCollectionPluginV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseRemoveCollectionPluginV1Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getRemoveCollectionPluginV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var REMOVE_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR = 24;
function getRemoveExternalPluginAdapterV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(REMOVE_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR);
}
function getRemoveExternalPluginAdapterV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["key", getExternalPluginAdapterKeyEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: REMOVE_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR
    })
  );
}
function getRemoveExternalPluginAdapterV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["key", getExternalPluginAdapterKeyDecoder()]
  ]);
}
function getRemoveExternalPluginAdapterV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getRemoveExternalPluginAdapterV1InstructionDataEncoder(),
    getRemoveExternalPluginAdapterV1InstructionDataDecoder()
  );
}
function getRemoveExternalPluginAdapterV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getRemoveExternalPluginAdapterV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseRemoveExternalPluginAdapterV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getRemoveExternalPluginAdapterV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var REMOVE_PLUGIN_V1_DISCRIMINATOR = 4;
function getRemovePluginV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(REMOVE_PLUGIN_V1_DISCRIMINATOR);
}
function getRemovePluginV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["pluginType", getPluginTypeEncoder()]
    ]),
    (value) => ({ ...value, discriminator: REMOVE_PLUGIN_V1_DISCRIMINATOR })
  );
}
function getRemovePluginV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["pluginType", getPluginTypeDecoder()]
  ]);
}
function getRemovePluginV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getRemovePluginV1InstructionDataEncoder(),
    getRemovePluginV1InstructionDataDecoder()
  );
}
function getRemovePluginV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getRemovePluginV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseRemovePluginV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getRemovePluginV1InstructionDataDecoder().decode(instruction.data)
  };
}
var REVOKE_COLLECTION_PLUGIN_AUTHORITY_V1_DISCRIMINATOR = 11;
function getRevokeCollectionPluginAuthorityV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(
    REVOKE_COLLECTION_PLUGIN_AUTHORITY_V1_DISCRIMINATOR
  );
}
function getRevokeCollectionPluginAuthorityV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["pluginType", getPluginTypeEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: REVOKE_COLLECTION_PLUGIN_AUTHORITY_V1_DISCRIMINATOR
    })
  );
}
function getRevokeCollectionPluginAuthorityV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["pluginType", getPluginTypeDecoder()]
  ]);
}
function getRevokeCollectionPluginAuthorityV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getRevokeCollectionPluginAuthorityV1InstructionDataEncoder(),
    getRevokeCollectionPluginAuthorityV1InstructionDataDecoder()
  );
}
function getRevokeCollectionPluginAuthorityV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getRevokeCollectionPluginAuthorityV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseRevokeCollectionPluginAuthorityV1Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getRevokeCollectionPluginAuthorityV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var REVOKE_PLUGIN_AUTHORITY_V1_DISCRIMINATOR = 10;
function getRevokePluginAuthorityV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(REVOKE_PLUGIN_AUTHORITY_V1_DISCRIMINATOR);
}
function getRevokePluginAuthorityV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["pluginType", getPluginTypeEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: REVOKE_PLUGIN_AUTHORITY_V1_DISCRIMINATOR
    })
  );
}
function getRevokePluginAuthorityV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["pluginType", getPluginTypeDecoder()]
  ]);
}
function getRevokePluginAuthorityV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getRevokePluginAuthorityV1InstructionDataEncoder(),
    getRevokePluginAuthorityV1InstructionDataDecoder()
  );
}
function getRevokePluginAuthorityV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getRevokePluginAuthorityV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseRevokePluginAuthorityV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getRevokePluginAuthorityV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var TRANSFER_V1_DISCRIMINATOR = 14;
function getTransferV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(TRANSFER_V1_DISCRIMINATOR);
}
function getTransferV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["compressionProof", web3_js.getOptionEncoder(getCompressionProofEncoder())]
    ]),
    (value) => ({ ...value, discriminator: TRANSFER_V1_DISCRIMINATOR })
  );
}
function getTransferV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["compressionProof", web3_js.getOptionDecoder(getCompressionProofDecoder())]
  ]);
}
function getTransferV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getTransferV1InstructionDataEncoder(),
    getTransferV1InstructionDataDecoder()
  );
}
function getTransferV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    newOwner: { value: input.newOwner ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.newOwner),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getTransferV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseTransferV1Instruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      newOwner: getNextAccount(),
      systemProgram: getNextOptionalAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getTransferV1InstructionDataDecoder().decode(instruction.data)
  };
}
var UPDATE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR = 27;
function getUpdateCollectionExternalPluginAdapterV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(
    UPDATE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR
  );
}
function getUpdateCollectionExternalPluginAdapterV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["key", getExternalPluginAdapterKeyEncoder()],
      ["updateInfo", getExternalPluginAdapterUpdateInfoEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: UPDATE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR
    })
  );
}
function getUpdateCollectionExternalPluginAdapterV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["key", getExternalPluginAdapterKeyDecoder()],
    ["updateInfo", getExternalPluginAdapterUpdateInfoDecoder()]
  ]);
}
function getUpdateCollectionExternalPluginAdapterV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getUpdateCollectionExternalPluginAdapterV1InstructionDataEncoder(),
    getUpdateCollectionExternalPluginAdapterV1InstructionDataDecoder()
  );
}
function getUpdateCollectionExternalPluginAdapterV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getUpdateCollectionExternalPluginAdapterV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpdateCollectionExternalPluginAdapterV1Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getUpdateCollectionExternalPluginAdapterV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var UPDATE_COLLECTION_PLUGIN_V1_DISCRIMINATOR = 7;
function getUpdateCollectionPluginV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(UPDATE_COLLECTION_PLUGIN_V1_DISCRIMINATOR);
}
function getUpdateCollectionPluginV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["plugin", getPluginEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: UPDATE_COLLECTION_PLUGIN_V1_DISCRIMINATOR
    })
  );
}
function getUpdateCollectionPluginV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["plugin", getPluginDecoder()]
  ]);
}
function getUpdateCollectionPluginV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getUpdateCollectionPluginV1InstructionDataEncoder(),
    getUpdateCollectionPluginV1InstructionDataDecoder()
  );
}
function getUpdateCollectionPluginV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getUpdateCollectionPluginV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpdateCollectionPluginV1Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getUpdateCollectionPluginV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var UPDATE_COLLECTION_V1_DISCRIMINATOR = 16;
function getUpdateCollectionV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(UPDATE_COLLECTION_V1_DISCRIMINATOR);
}
function getUpdateCollectionV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      [
        "newName",
        web3_js.getOptionEncoder(
          web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())
        )
      ],
      [
        "newUri",
        web3_js.getOptionEncoder(
          web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())
        )
      ]
    ]),
    (value) => ({ ...value, discriminator: UPDATE_COLLECTION_V1_DISCRIMINATOR })
  );
}
function getUpdateCollectionV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    [
      "newName",
      web3_js.getOptionDecoder(web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder()))
    ],
    [
      "newUri",
      web3_js.getOptionDecoder(web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder()))
    ]
  ]);
}
function getUpdateCollectionV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getUpdateCollectionV1InstructionDataEncoder(),
    getUpdateCollectionV1InstructionDataDecoder()
  );
}
function getUpdateCollectionV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    newUpdateAuthority: {
      value: input.newUpdateAuthority ?? null,
      isWritable: false
    },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.newUpdateAuthority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getUpdateCollectionV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpdateCollectionV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      newUpdateAuthority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getUpdateCollectionV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var UPDATE_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR = 26;
function getUpdateExternalPluginAdapterV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(UPDATE_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR);
}
function getUpdateExternalPluginAdapterV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["key", getExternalPluginAdapterKeyEncoder()],
      ["updateInfo", getExternalPluginAdapterUpdateInfoEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: UPDATE_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR
    })
  );
}
function getUpdateExternalPluginAdapterV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["key", getExternalPluginAdapterKeyDecoder()],
    ["updateInfo", getExternalPluginAdapterUpdateInfoDecoder()]
  ]);
}
function getUpdateExternalPluginAdapterV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getUpdateExternalPluginAdapterV1InstructionDataEncoder(),
    getUpdateExternalPluginAdapterV1InstructionDataDecoder()
  );
}
function getUpdateExternalPluginAdapterV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getUpdateExternalPluginAdapterV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpdateExternalPluginAdapterV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getUpdateExternalPluginAdapterV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var UPDATE_PLUGIN_V1_DISCRIMINATOR = 6;
function getUpdatePluginV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(UPDATE_PLUGIN_V1_DISCRIMINATOR);
}
function getUpdatePluginV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["plugin", getPluginEncoder()]
    ]),
    (value) => ({ ...value, discriminator: UPDATE_PLUGIN_V1_DISCRIMINATOR })
  );
}
function getUpdatePluginV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["plugin", getPluginDecoder()]
  ]);
}
function getUpdatePluginV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getUpdatePluginV1InstructionDataEncoder(),
    getUpdatePluginV1InstructionDataDecoder()
  );
}
function getUpdatePluginV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getUpdatePluginV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpdatePluginV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getUpdatePluginV1InstructionDataDecoder().decode(instruction.data)
  };
}
var UPDATE_V1_DISCRIMINATOR = 15;
function getUpdateV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(UPDATE_V1_DISCRIMINATOR);
}
function getUpdateV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      [
        "newName",
        web3_js.getOptionEncoder(
          web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())
        )
      ],
      [
        "newUri",
        web3_js.getOptionEncoder(
          web3_js.addEncoderSizePrefix(web3_js.getUtf8Encoder(), web3_js.getU32Encoder())
        )
      ],
      ["newUpdateAuthority", web3_js.getOptionEncoder(getUpdateAuthorityEncoder())]
    ]),
    (value) => ({ ...value, discriminator: UPDATE_V1_DISCRIMINATOR })
  );
}
function getUpdateV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    [
      "newName",
      web3_js.getOptionDecoder(web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder()))
    ],
    [
      "newUri",
      web3_js.getOptionDecoder(web3_js.addDecoderSizePrefix(web3_js.getUtf8Decoder(), web3_js.getU32Decoder()))
    ],
    ["newUpdateAuthority", web3_js.getOptionDecoder(getUpdateAuthorityDecoder())]
  ]);
}
function getUpdateV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getUpdateV1InstructionDataEncoder(),
    getUpdateV1InstructionDataDecoder()
  );
}
function getUpdateV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: false },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getUpdateV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpdateV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getUpdateV1InstructionDataDecoder().decode(instruction.data)
  };
}
var WRITE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_DATA_V1_DISCRIMINATOR = 29;
function getWriteCollectionExternalPluginAdapterDataV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(
    WRITE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_DATA_V1_DISCRIMINATOR
  );
}
function getWriteCollectionExternalPluginAdapterDataV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["key", getExternalPluginAdapterKeyEncoder()],
      ["data", web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: WRITE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_DATA_V1_DISCRIMINATOR
    })
  );
}
function getWriteCollectionExternalPluginAdapterDataV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["key", getExternalPluginAdapterKeyDecoder()],
    ["data", web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder())]
  ]);
}
function getWriteCollectionExternalPluginAdapterDataV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getWriteCollectionExternalPluginAdapterDataV1InstructionDataEncoder(),
    getWriteCollectionExternalPluginAdapterDataV1InstructionDataDecoder()
  );
}
function getWriteCollectionExternalPluginAdapterDataV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getWriteCollectionExternalPluginAdapterDataV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWriteCollectionExternalPluginAdapterDataV1Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      collection: getNextAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getWriteCollectionExternalPluginAdapterDataV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var WRITE_EXTERNAL_PLUGIN_ADAPTER_DATA_V1_DISCRIMINATOR = 28;
function getWriteExternalPluginAdapterDataV1DiscriminatorBytes() {
  return web3_js.getU8Encoder().encode(
    WRITE_EXTERNAL_PLUGIN_ADAPTER_DATA_V1_DISCRIMINATOR
  );
}
function getWriteExternalPluginAdapterDataV1InstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["key", getExternalPluginAdapterKeyEncoder()],
      ["data", web3_js.addEncoderSizePrefix(web3_js.getBytesEncoder(), web3_js.getU32Encoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: WRITE_EXTERNAL_PLUGIN_ADAPTER_DATA_V1_DISCRIMINATOR
    })
  );
}
function getWriteExternalPluginAdapterDataV1InstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["key", getExternalPluginAdapterKeyDecoder()],
    ["data", web3_js.addDecoderSizePrefix(web3_js.getBytesDecoder(), web3_js.getU32Decoder())]
  ]);
}
function getWriteExternalPluginAdapterDataV1InstructionDataCodec() {
  return web3_js.combineCodec(
    getWriteExternalPluginAdapterDataV1InstructionDataEncoder(),
    getWriteExternalPluginAdapterDataV1InstructionDataDecoder()
  );
}
function getWriteExternalPluginAdapterDataV1Instruction(input, config) {
  const programAddress = config?.programAddress ?? MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
  const originalAccounts = {
    asset: { value: input.asset ?? null, isWritable: true },
    collection: { value: input.collection ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    authority: { value: input.authority ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    logWrapper: { value: input.logWrapper ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.asset),
      getAccountMeta(accounts.collection),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.authority),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.logWrapper)
    ],
    programAddress,
    data: getWriteExternalPluginAdapterDataV1InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWriteExternalPluginAdapterDataV1Instruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === MPL_CORE_PROGRAM_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      asset: getNextAccount(),
      collection: getNextOptionalAccount(),
      payer: getNextAccount(),
      authority: getNextOptionalAccount(),
      systemProgram: getNextAccount(),
      logWrapper: getNextOptionalAccount()
    },
    data: getWriteExternalPluginAdapterDataV1InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
var createAsset = async (args) => {
  const {
    client,
    payer,
    authority: authority2,
    updateAuthority: updateAuthority2,
    owner,
    name,
    uri,
    plugins,
    collection,
    asset_kp = await web3_js.generateKeyPairSigner()
  } = args;
  if (collection && updateAuthority2)
    throw new Error("Cannot specify both collection and updateAuthority");
  const ix = getCreateV2Instruction({
    asset: asset_kp,
    payer,
    owner,
    authority: authority2,
    updateAuthority: updateAuthority2,
    collection,
    dataState: 0 /* AccountState */,
    name,
    uri,
    plugins,
    externalPluginAdapters: null
  });
  const signature = await web3_js.pipe(
    await testHelpers.createDefaultTransaction(client, payer),
    (tx) => web3_js.appendTransactionMessageInstruction(ix, tx),
    (tx) => testHelpers.signAndSendTransaction(client, tx)
  );
  return { signature, address: asset_kp.address };
};
var createDefaultAsset = async (args) => {
  const {
    client,
    payer,
    authority: authority2,
    updateAuthority: updateAuthority2,
    owner,
    royalties,
    collection,
    name,
    uri
  } = args;
  let plugins = null;
  if (royalties) {
    const royalty = [
      {
        basisPoints: royalties.basisPoints ?? 500,
        creators: royalties.creators ?? [],
        ruleSet: {
          __kind: "None"
        }
      }
    ];
    plugins = [
      {
        plugin: {
          __kind: "Royalties",
          fields: royalty
        },
        authority: { __kind: "UpdateAuthority" }
      }
    ];
  }
  const { address } = await createAsset({
    client,
    payer,
    authority: authority2,
    updateAuthority: updateAuthority2,
    owner,
    name: name ?? "TestAsset",
    uri: uri ?? "https://example.com/nft",
    plugins,
    collection
  });
  return await fetchAssetV1(client.rpc, address);
};
var createCollection = async (args) => {
  const {
    client,
    payer,
    updateAuthority: updateAuthority2,
    plugins,
    collection_kp = await web3_js.generateKeyPairSigner()
  } = args;
  const createCollectionIx = getCreateCollectionV1Instruction({
    collection: collection_kp,
    payer,
    updateAuthority: updateAuthority2,
    name: "TestCollection",
    uri: "https://example.com/collection",
    plugins
  });
  const signature = await web3_js.pipe(
    await testHelpers.createDefaultTransaction(client, payer),
    (tx) => web3_js.appendTransactionMessageInstruction(createCollectionIx, tx),
    (tx) => testHelpers.signAndSendTransaction(client, tx)
  );
  return { signature, address: collection_kp.address };
};
var createDefaultCollection = async (args) => {
  const {
    client,
    payer,
    updateAuthority: updateAuthority2,
    royalties = {
      creators: [
        {
          address: updateAuthority2,
          percentage: 100
        }
      ],
      basisPoints: 500
    }
  } = args;
  const royaltyArgs = [
    {
      basisPoints: royalties.basisPoints,
      creators: royalties.creators,
      ruleSet: {
        __kind: "None"
      }
    }
  ];
  const plugins = [
    {
      plugin: {
        __kind: "Royalties",
        fields: royaltyArgs
      },
      authority: { __kind: "UpdateAuthority" }
    }
  ];
  const { address } = await createCollection({
    client,
    payer,
    updateAuthority: updateAuthority2,
    plugins
  });
  return await fetchCollectionV1(client.rpc, address);
};
var createDefaultAssetWithCollection = async (args) => {
  const { client, payer, collectionAuthority, owner, royalties } = args;
  const collection = await createDefaultCollection({
    client,
    payer,
    updateAuthority: collectionAuthority.address,
    royalties
  });
  const asset = await createDefaultAsset({
    client,
    payer,
    owner,
    authority: collectionAuthority,
    collection: collection.address
  });
  return [asset, collection];
};

// src/helpers/fetchPlugins.ts
var BASE_ASSET_SIZE = 75;
var BASE_COLLECTION_SIZE = 49;
async function fetchAssetPlugin(client, address, pluginType) {
  const data = (await client.rpc.getAccountInfo(address, { encoding: "base64" }).send()).value.data;
  const buffer = new Uint8Array(Buffer.from(String(data), "base64"));
  const asset = getAssetV1Decoder().decode(buffer);
  const assetSize = BASE_ASSET_SIZE + asset.name.length + asset.uri.length;
  const header = getPluginHeaderV1Decoder().decode(buffer.subarray(assetSize));
  const pluginRegistry = getPluginRegistryV1Decoder().decode(
    buffer.subarray(Number(header.pluginRegistryOffset))
  );
  const pluginRecord = pluginRegistry.registry.find(
    (plugin3) => plugin3.pluginType === pluginType
  );
  if (!pluginRecord) {
    return null;
  }
  const plugin2 = getPluginDecoder().decode(
    buffer,
    Number(pluginRecord.offset)
  );
  return plugin2;
}
async function fetchCollectionPlugin(client, address, pluginType) {
  const data = (await client.rpc.getAccountInfo(address, { encoding: "base64" }).send()).value.data;
  const buffer = new Uint8Array(Buffer.from(String(data), "base64"));
  const collection = getCollectionV1Decoder().decode(buffer);
  const collectionSize = BASE_COLLECTION_SIZE + collection.name.length + collection.uri.length;
  const header = getPluginHeaderV1Decoder().decode(
    buffer.subarray(collectionSize)
  );
  const pluginRegistry = getPluginRegistryV1Decoder().decode(
    buffer.subarray(Number(header.pluginRegistryOffset))
  );
  const pluginRecord = pluginRegistry.registry.find(
    (plugin3) => plugin3.pluginType === pluginType
  );
  if (!pluginRecord) {
    return null;
  }
  const plugin2 = getPluginDecoder().decode(
    buffer,
    Number(pluginRecord.offset)
  );
  return plugin2;
}

exports.ADD_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR = ADD_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR;
exports.ADD_COLLECTION_PLUGIN_V1_DISCRIMINATOR = ADD_COLLECTION_PLUGIN_V1_DISCRIMINATOR;
exports.ADD_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR = ADD_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR;
exports.ADD_PLUGIN_V1_DISCRIMINATOR = ADD_PLUGIN_V1_DISCRIMINATOR;
exports.APPROVE_COLLECTION_PLUGIN_AUTHORITY_V1_DISCRIMINATOR = APPROVE_COLLECTION_PLUGIN_AUTHORITY_V1_DISCRIMINATOR;
exports.APPROVE_PLUGIN_AUTHORITY_V1_DISCRIMINATOR = APPROVE_PLUGIN_AUTHORITY_V1_DISCRIMINATOR;
exports.BURN_COLLECTION_V1_DISCRIMINATOR = BURN_COLLECTION_V1_DISCRIMINATOR;
exports.BURN_V1_DISCRIMINATOR = BURN_V1_DISCRIMINATOR;
exports.COLLECT_DISCRIMINATOR = COLLECT_DISCRIMINATOR;
exports.COMPRESS_V1_DISCRIMINATOR = COMPRESS_V1_DISCRIMINATOR;
exports.CREATE_COLLECTION_V1_DISCRIMINATOR = CREATE_COLLECTION_V1_DISCRIMINATOR;
exports.CREATE_COLLECTION_V2_DISCRIMINATOR = CREATE_COLLECTION_V2_DISCRIMINATOR;
exports.CREATE_V1_DISCRIMINATOR = CREATE_V1_DISCRIMINATOR;
exports.CREATE_V2_DISCRIMINATOR = CREATE_V2_DISCRIMINATOR;
exports.DECOMPRESS_V1_DISCRIMINATOR = DECOMPRESS_V1_DISCRIMINATOR;
exports.DataState = DataState;
exports.ExternalPluginAdapterSchema = ExternalPluginAdapterSchema;
exports.ExternalPluginAdapterType = ExternalPluginAdapterType;
exports.ExternalValidationResult = ExternalValidationResult;
exports.HookableLifecycleEvent = HookableLifecycleEvent;
exports.Key = Key;
exports.MPL_CORE_PROGRAM_ERROR__ALREADY_COMPRESSED = MPL_CORE_PROGRAM_ERROR__ALREADY_COMPRESSED;
exports.MPL_CORE_PROGRAM_ERROR__ALREADY_DECOMPRESSED = MPL_CORE_PROGRAM_ERROR__ALREADY_DECOMPRESSED;
exports.MPL_CORE_PROGRAM_ERROR__ASSET_IS_FROZEN = MPL_CORE_PROGRAM_ERROR__ASSET_IS_FROZEN;
exports.MPL_CORE_PROGRAM_ERROR__CANNOT_BURN_COLLECTION = MPL_CORE_PROGRAM_ERROR__CANNOT_BURN_COLLECTION;
exports.MPL_CORE_PROGRAM_ERROR__CANNOT_MIGRATE_MASTER_WITH_SUPPLY = MPL_CORE_PROGRAM_ERROR__CANNOT_MIGRATE_MASTER_WITH_SUPPLY;
exports.MPL_CORE_PROGRAM_ERROR__CANNOT_MIGRATE_PRINTS = MPL_CORE_PROGRAM_ERROR__CANNOT_MIGRATE_PRINTS;
exports.MPL_CORE_PROGRAM_ERROR__CANNOT_REDELEGATE = MPL_CORE_PROGRAM_ERROR__CANNOT_REDELEGATE;
exports.MPL_CORE_PROGRAM_ERROR__CONFLICTING_AUTHORITY = MPL_CORE_PROGRAM_ERROR__CONFLICTING_AUTHORITY;
exports.MPL_CORE_PROGRAM_ERROR__DESERIALIZATION_ERROR = MPL_CORE_PROGRAM_ERROR__DESERIALIZATION_ERROR;
exports.MPL_CORE_PROGRAM_ERROR__DUPLICATE_LIFECYCLE_CHECKS = MPL_CORE_PROGRAM_ERROR__DUPLICATE_LIFECYCLE_CHECKS;
exports.MPL_CORE_PROGRAM_ERROR__EXTERNAL_PLUGIN_ADAPTER_ALREADY_EXISTS = MPL_CORE_PROGRAM_ERROR__EXTERNAL_PLUGIN_ADAPTER_ALREADY_EXISTS;
exports.MPL_CORE_PROGRAM_ERROR__EXTERNAL_PLUGIN_ADAPTER_NOT_FOUND = MPL_CORE_PROGRAM_ERROR__EXTERNAL_PLUGIN_ADAPTER_NOT_FOUND;
exports.MPL_CORE_PROGRAM_ERROR__INCORRECT_ACCOUNT = MPL_CORE_PROGRAM_ERROR__INCORRECT_ACCOUNT;
exports.MPL_CORE_PROGRAM_ERROR__INCORRECT_ASSET_HASH = MPL_CORE_PROGRAM_ERROR__INCORRECT_ASSET_HASH;
exports.MPL_CORE_PROGRAM_ERROR__INVALID_ASSET = MPL_CORE_PROGRAM_ERROR__INVALID_ASSET;
exports.MPL_CORE_PROGRAM_ERROR__INVALID_AUTHORITY = MPL_CORE_PROGRAM_ERROR__INVALID_AUTHORITY;
exports.MPL_CORE_PROGRAM_ERROR__INVALID_COLLECTION = MPL_CORE_PROGRAM_ERROR__INVALID_COLLECTION;
exports.MPL_CORE_PROGRAM_ERROR__INVALID_LOG_WRAPPER_PROGRAM = MPL_CORE_PROGRAM_ERROR__INVALID_LOG_WRAPPER_PROGRAM;
exports.MPL_CORE_PROGRAM_ERROR__INVALID_ORACLE_ACCOUNT_DATA = MPL_CORE_PROGRAM_ERROR__INVALID_ORACLE_ACCOUNT_DATA;
exports.MPL_CORE_PROGRAM_ERROR__INVALID_PLUGIN = MPL_CORE_PROGRAM_ERROR__INVALID_PLUGIN;
exports.MPL_CORE_PROGRAM_ERROR__INVALID_PLUGIN_OPERATION = MPL_CORE_PROGRAM_ERROR__INVALID_PLUGIN_OPERATION;
exports.MPL_CORE_PROGRAM_ERROR__INVALID_PLUGIN_SETTING = MPL_CORE_PROGRAM_ERROR__INVALID_PLUGIN_SETTING;
exports.MPL_CORE_PROGRAM_ERROR__INVALID_SYSTEM_PROGRAM = MPL_CORE_PROGRAM_ERROR__INVALID_SYSTEM_PROGRAM;
exports.MPL_CORE_PROGRAM_ERROR__MISSING_ASSET = MPL_CORE_PROGRAM_ERROR__MISSING_ASSET;
exports.MPL_CORE_PROGRAM_ERROR__MISSING_COLLECTION = MPL_CORE_PROGRAM_ERROR__MISSING_COLLECTION;
exports.MPL_CORE_PROGRAM_ERROR__MISSING_COMPRESSION_PROOF = MPL_CORE_PROGRAM_ERROR__MISSING_COMPRESSION_PROOF;
exports.MPL_CORE_PROGRAM_ERROR__MISSING_EXTERNAL_PLUGIN_ADAPTER_ACCOUNT = MPL_CORE_PROGRAM_ERROR__MISSING_EXTERNAL_PLUGIN_ADAPTER_ACCOUNT;
exports.MPL_CORE_PROGRAM_ERROR__MISSING_NEW_OWNER = MPL_CORE_PROGRAM_ERROR__MISSING_NEW_OWNER;
exports.MPL_CORE_PROGRAM_ERROR__MISSING_SIGNER = MPL_CORE_PROGRAM_ERROR__MISSING_SIGNER;
exports.MPL_CORE_PROGRAM_ERROR__MISSING_SYSTEM_PROGRAM = MPL_CORE_PROGRAM_ERROR__MISSING_SYSTEM_PROGRAM;
exports.MPL_CORE_PROGRAM_ERROR__MISSING_UPDATE_AUTHORITY = MPL_CORE_PROGRAM_ERROR__MISSING_UPDATE_AUTHORITY;
exports.MPL_CORE_PROGRAM_ERROR__NOT_AVAILABLE = MPL_CORE_PROGRAM_ERROR__NOT_AVAILABLE;
exports.MPL_CORE_PROGRAM_ERROR__NO_APPROVALS = MPL_CORE_PROGRAM_ERROR__NO_APPROVALS;
exports.MPL_CORE_PROGRAM_ERROR__NUMERICAL_OVERFLOW = MPL_CORE_PROGRAM_ERROR__NUMERICAL_OVERFLOW;
exports.MPL_CORE_PROGRAM_ERROR__NUMERICAL_OVERFLOW_ERROR = MPL_CORE_PROGRAM_ERROR__NUMERICAL_OVERFLOW_ERROR;
exports.MPL_CORE_PROGRAM_ERROR__ORACLE_CAN_REJECT_ONLY = MPL_CORE_PROGRAM_ERROR__ORACLE_CAN_REJECT_ONLY;
exports.MPL_CORE_PROGRAM_ERROR__PLUGINS_NOT_INITIALIZED = MPL_CORE_PROGRAM_ERROR__PLUGINS_NOT_INITIALIZED;
exports.MPL_CORE_PROGRAM_ERROR__PLUGIN_ALREADY_EXISTS = MPL_CORE_PROGRAM_ERROR__PLUGIN_ALREADY_EXISTS;
exports.MPL_CORE_PROGRAM_ERROR__PLUGIN_NOT_FOUND = MPL_CORE_PROGRAM_ERROR__PLUGIN_NOT_FOUND;
exports.MPL_CORE_PROGRAM_ERROR__REQUIRES_LIFECYCLE_CHECK = MPL_CORE_PROGRAM_ERROR__REQUIRES_LIFECYCLE_CHECK;
exports.MPL_CORE_PROGRAM_ERROR__SERIALIZATION_ERROR = MPL_CORE_PROGRAM_ERROR__SERIALIZATION_ERROR;
exports.MPL_CORE_PROGRAM_ERROR__UNINITIALIZED_ORACLE_ACCOUNT = MPL_CORE_PROGRAM_ERROR__UNINITIALIZED_ORACLE_ACCOUNT;
exports.MPL_CORE_PROGRAM_PROGRAM_ADDRESS = MPL_CORE_PROGRAM_PROGRAM_ADDRESS;
exports.MplCoreProgramAccount = MplCoreProgramAccount;
exports.MplCoreProgramInstruction = MplCoreProgramInstruction;
exports.PluginType = PluginType;
exports.REMOVE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR = REMOVE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR;
exports.REMOVE_COLLECTION_PLUGIN_V1_DISCRIMINATOR = REMOVE_COLLECTION_PLUGIN_V1_DISCRIMINATOR;
exports.REMOVE_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR = REMOVE_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR;
exports.REMOVE_PLUGIN_V1_DISCRIMINATOR = REMOVE_PLUGIN_V1_DISCRIMINATOR;
exports.REVOKE_COLLECTION_PLUGIN_AUTHORITY_V1_DISCRIMINATOR = REVOKE_COLLECTION_PLUGIN_AUTHORITY_V1_DISCRIMINATOR;
exports.REVOKE_PLUGIN_AUTHORITY_V1_DISCRIMINATOR = REVOKE_PLUGIN_AUTHORITY_V1_DISCRIMINATOR;
exports.TRANSFER_V1_DISCRIMINATOR = TRANSFER_V1_DISCRIMINATOR;
exports.UPDATE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR = UPDATE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR;
exports.UPDATE_COLLECTION_PLUGIN_V1_DISCRIMINATOR = UPDATE_COLLECTION_PLUGIN_V1_DISCRIMINATOR;
exports.UPDATE_COLLECTION_V1_DISCRIMINATOR = UPDATE_COLLECTION_V1_DISCRIMINATOR;
exports.UPDATE_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR = UPDATE_EXTERNAL_PLUGIN_ADAPTER_V1_DISCRIMINATOR;
exports.UPDATE_PLUGIN_V1_DISCRIMINATOR = UPDATE_PLUGIN_V1_DISCRIMINATOR;
exports.UPDATE_V1_DISCRIMINATOR = UPDATE_V1_DISCRIMINATOR;
exports.ValidationResult = ValidationResult;
exports.WRITE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_DATA_V1_DISCRIMINATOR = WRITE_COLLECTION_EXTERNAL_PLUGIN_ADAPTER_DATA_V1_DISCRIMINATOR;
exports.WRITE_EXTERNAL_PLUGIN_ADAPTER_DATA_V1_DISCRIMINATOR = WRITE_EXTERNAL_PLUGIN_ADAPTER_DATA_V1_DISCRIMINATOR;
exports.authority = authority;
exports.createAsset = createAsset;
exports.createCollection = createCollection;
exports.createDefaultAsset = createDefaultAsset;
exports.createDefaultAssetWithCollection = createDefaultAssetWithCollection;
exports.createDefaultCollection = createDefaultCollection;
exports.decodeAssetV1 = decodeAssetV1;
exports.decodeCollectionV1 = decodeCollectionV1;
exports.decodeHashedAssetV1 = decodeHashedAssetV1;
exports.decodePluginHeaderV1 = decodePluginHeaderV1;
exports.decodePluginRegistryV1 = decodePluginRegistryV1;
exports.externalPluginAdapter = externalPluginAdapter;
exports.externalPluginAdapterInitInfo = externalPluginAdapterInitInfo;
exports.externalPluginAdapterKey = externalPluginAdapterKey;
exports.externalPluginAdapterUpdateInfo = externalPluginAdapterUpdateInfo;
exports.extraAccount = extraAccount;
exports.fetchAllAssetV1 = fetchAllAssetV1;
exports.fetchAllCollectionV1 = fetchAllCollectionV1;
exports.fetchAllHashedAssetV1 = fetchAllHashedAssetV1;
exports.fetchAllMaybeAssetV1 = fetchAllMaybeAssetV1;
exports.fetchAllMaybeCollectionV1 = fetchAllMaybeCollectionV1;
exports.fetchAllMaybeHashedAssetV1 = fetchAllMaybeHashedAssetV1;
exports.fetchAllMaybePluginHeaderV1 = fetchAllMaybePluginHeaderV1;
exports.fetchAllMaybePluginRegistryV1 = fetchAllMaybePluginRegistryV1;
exports.fetchAllPluginHeaderV1 = fetchAllPluginHeaderV1;
exports.fetchAllPluginRegistryV1 = fetchAllPluginRegistryV1;
exports.fetchAssetPlugin = fetchAssetPlugin;
exports.fetchAssetV1 = fetchAssetV1;
exports.fetchCollectionPlugin = fetchCollectionPlugin;
exports.fetchCollectionV1 = fetchCollectionV1;
exports.fetchHashedAssetV1 = fetchHashedAssetV1;
exports.fetchMaybeAssetV1 = fetchMaybeAssetV1;
exports.fetchMaybeCollectionV1 = fetchMaybeCollectionV1;
exports.fetchMaybeHashedAssetV1 = fetchMaybeHashedAssetV1;
exports.fetchMaybePluginHeaderV1 = fetchMaybePluginHeaderV1;
exports.fetchMaybePluginRegistryV1 = fetchMaybePluginRegistryV1;
exports.fetchPluginHeaderV1 = fetchPluginHeaderV1;
exports.fetchPluginRegistryV1 = fetchPluginRegistryV1;
exports.getAddBlockerCodec = getAddBlockerCodec;
exports.getAddBlockerDecoder = getAddBlockerDecoder;
exports.getAddBlockerEncoder = getAddBlockerEncoder;
exports.getAddCollectionExternalPluginAdapterV1DiscriminatorBytes = getAddCollectionExternalPluginAdapterV1DiscriminatorBytes;
exports.getAddCollectionExternalPluginAdapterV1Instruction = getAddCollectionExternalPluginAdapterV1Instruction;
exports.getAddCollectionExternalPluginAdapterV1InstructionDataCodec = getAddCollectionExternalPluginAdapterV1InstructionDataCodec;
exports.getAddCollectionExternalPluginAdapterV1InstructionDataDecoder = getAddCollectionExternalPluginAdapterV1InstructionDataDecoder;
exports.getAddCollectionExternalPluginAdapterV1InstructionDataEncoder = getAddCollectionExternalPluginAdapterV1InstructionDataEncoder;
exports.getAddCollectionPluginV1DiscriminatorBytes = getAddCollectionPluginV1DiscriminatorBytes;
exports.getAddCollectionPluginV1Instruction = getAddCollectionPluginV1Instruction;
exports.getAddCollectionPluginV1InstructionDataCodec = getAddCollectionPluginV1InstructionDataCodec;
exports.getAddCollectionPluginV1InstructionDataDecoder = getAddCollectionPluginV1InstructionDataDecoder;
exports.getAddCollectionPluginV1InstructionDataEncoder = getAddCollectionPluginV1InstructionDataEncoder;
exports.getAddExternalPluginAdapterV1DiscriminatorBytes = getAddExternalPluginAdapterV1DiscriminatorBytes;
exports.getAddExternalPluginAdapterV1Instruction = getAddExternalPluginAdapterV1Instruction;
exports.getAddExternalPluginAdapterV1InstructionDataCodec = getAddExternalPluginAdapterV1InstructionDataCodec;
exports.getAddExternalPluginAdapterV1InstructionDataDecoder = getAddExternalPluginAdapterV1InstructionDataDecoder;
exports.getAddExternalPluginAdapterV1InstructionDataEncoder = getAddExternalPluginAdapterV1InstructionDataEncoder;
exports.getAddPluginV1DiscriminatorBytes = getAddPluginV1DiscriminatorBytes;
exports.getAddPluginV1Instruction = getAddPluginV1Instruction;
exports.getAddPluginV1InstructionDataCodec = getAddPluginV1InstructionDataCodec;
exports.getAddPluginV1InstructionDataDecoder = getAddPluginV1InstructionDataDecoder;
exports.getAddPluginV1InstructionDataEncoder = getAddPluginV1InstructionDataEncoder;
exports.getApproveCollectionPluginAuthorityV1DiscriminatorBytes = getApproveCollectionPluginAuthorityV1DiscriminatorBytes;
exports.getApproveCollectionPluginAuthorityV1Instruction = getApproveCollectionPluginAuthorityV1Instruction;
exports.getApproveCollectionPluginAuthorityV1InstructionDataCodec = getApproveCollectionPluginAuthorityV1InstructionDataCodec;
exports.getApproveCollectionPluginAuthorityV1InstructionDataDecoder = getApproveCollectionPluginAuthorityV1InstructionDataDecoder;
exports.getApproveCollectionPluginAuthorityV1InstructionDataEncoder = getApproveCollectionPluginAuthorityV1InstructionDataEncoder;
exports.getApprovePluginAuthorityV1DiscriminatorBytes = getApprovePluginAuthorityV1DiscriminatorBytes;
exports.getApprovePluginAuthorityV1Instruction = getApprovePluginAuthorityV1Instruction;
exports.getApprovePluginAuthorityV1InstructionDataCodec = getApprovePluginAuthorityV1InstructionDataCodec;
exports.getApprovePluginAuthorityV1InstructionDataDecoder = getApprovePluginAuthorityV1InstructionDataDecoder;
exports.getApprovePluginAuthorityV1InstructionDataEncoder = getApprovePluginAuthorityV1InstructionDataEncoder;
exports.getAssetV1Codec = getAssetV1Codec;
exports.getAssetV1Decoder = getAssetV1Decoder;
exports.getAssetV1Encoder = getAssetV1Encoder;
exports.getAttributeCodec = getAttributeCodec;
exports.getAttributeDecoder = getAttributeDecoder;
exports.getAttributeEncoder = getAttributeEncoder;
exports.getAttributesCodec = getAttributesCodec;
exports.getAttributesDecoder = getAttributesDecoder;
exports.getAttributesEncoder = getAttributesEncoder;
exports.getAuthorityCodec = getAuthorityCodec;
exports.getAuthorityDecoder = getAuthorityDecoder;
exports.getAuthorityEncoder = getAuthorityEncoder;
exports.getAutographCodec = getAutographCodec;
exports.getAutographDecoder = getAutographDecoder;
exports.getAutographEncoder = getAutographEncoder;
exports.getAutographSignatureCodec = getAutographSignatureCodec;
exports.getAutographSignatureDecoder = getAutographSignatureDecoder;
exports.getAutographSignatureEncoder = getAutographSignatureEncoder;
exports.getBurnCollectionV1DiscriminatorBytes = getBurnCollectionV1DiscriminatorBytes;
exports.getBurnCollectionV1Instruction = getBurnCollectionV1Instruction;
exports.getBurnCollectionV1InstructionDataCodec = getBurnCollectionV1InstructionDataCodec;
exports.getBurnCollectionV1InstructionDataDecoder = getBurnCollectionV1InstructionDataDecoder;
exports.getBurnCollectionV1InstructionDataEncoder = getBurnCollectionV1InstructionDataEncoder;
exports.getBurnDelegateCodec = getBurnDelegateCodec;
exports.getBurnDelegateDecoder = getBurnDelegateDecoder;
exports.getBurnDelegateEncoder = getBurnDelegateEncoder;
exports.getBurnV1DiscriminatorBytes = getBurnV1DiscriminatorBytes;
exports.getBurnV1Instruction = getBurnV1Instruction;
exports.getBurnV1InstructionDataCodec = getBurnV1InstructionDataCodec;
exports.getBurnV1InstructionDataDecoder = getBurnV1InstructionDataDecoder;
exports.getBurnV1InstructionDataEncoder = getBurnV1InstructionDataEncoder;
exports.getCollectDiscriminatorBytes = getCollectDiscriminatorBytes;
exports.getCollectInstruction = getCollectInstruction;
exports.getCollectInstructionDataCodec = getCollectInstructionDataCodec;
exports.getCollectInstructionDataDecoder = getCollectInstructionDataDecoder;
exports.getCollectInstructionDataEncoder = getCollectInstructionDataEncoder;
exports.getCollectionV1Codec = getCollectionV1Codec;
exports.getCollectionV1Decoder = getCollectionV1Decoder;
exports.getCollectionV1Encoder = getCollectionV1Encoder;
exports.getCompressV1DiscriminatorBytes = getCompressV1DiscriminatorBytes;
exports.getCompressV1Instruction = getCompressV1Instruction;
exports.getCompressV1InstructionDataCodec = getCompressV1InstructionDataCodec;
exports.getCompressV1InstructionDataDecoder = getCompressV1InstructionDataDecoder;
exports.getCompressV1InstructionDataEncoder = getCompressV1InstructionDataEncoder;
exports.getCompressionProofCodec = getCompressionProofCodec;
exports.getCompressionProofDecoder = getCompressionProofDecoder;
exports.getCompressionProofEncoder = getCompressionProofEncoder;
exports.getCreateCollectionV1DiscriminatorBytes = getCreateCollectionV1DiscriminatorBytes;
exports.getCreateCollectionV1Instruction = getCreateCollectionV1Instruction;
exports.getCreateCollectionV1InstructionDataCodec = getCreateCollectionV1InstructionDataCodec;
exports.getCreateCollectionV1InstructionDataDecoder = getCreateCollectionV1InstructionDataDecoder;
exports.getCreateCollectionV1InstructionDataEncoder = getCreateCollectionV1InstructionDataEncoder;
exports.getCreateCollectionV2DiscriminatorBytes = getCreateCollectionV2DiscriminatorBytes;
exports.getCreateCollectionV2Instruction = getCreateCollectionV2Instruction;
exports.getCreateCollectionV2InstructionDataCodec = getCreateCollectionV2InstructionDataCodec;
exports.getCreateCollectionV2InstructionDataDecoder = getCreateCollectionV2InstructionDataDecoder;
exports.getCreateCollectionV2InstructionDataEncoder = getCreateCollectionV2InstructionDataEncoder;
exports.getCreateV1DiscriminatorBytes = getCreateV1DiscriminatorBytes;
exports.getCreateV1Instruction = getCreateV1Instruction;
exports.getCreateV1InstructionDataCodec = getCreateV1InstructionDataCodec;
exports.getCreateV1InstructionDataDecoder = getCreateV1InstructionDataDecoder;
exports.getCreateV1InstructionDataEncoder = getCreateV1InstructionDataEncoder;
exports.getCreateV2DiscriminatorBytes = getCreateV2DiscriminatorBytes;
exports.getCreateV2Instruction = getCreateV2Instruction;
exports.getCreateV2InstructionDataCodec = getCreateV2InstructionDataCodec;
exports.getCreateV2InstructionDataDecoder = getCreateV2InstructionDataDecoder;
exports.getCreateV2InstructionDataEncoder = getCreateV2InstructionDataEncoder;
exports.getCreatorCodec = getCreatorCodec;
exports.getCreatorDecoder = getCreatorDecoder;
exports.getCreatorEncoder = getCreatorEncoder;
exports.getDataStateCodec = getDataStateCodec;
exports.getDataStateDecoder = getDataStateDecoder;
exports.getDataStateEncoder = getDataStateEncoder;
exports.getDataStoreCodec = getDataStoreCodec;
exports.getDataStoreDecoder = getDataStoreDecoder;
exports.getDataStoreEncoder = getDataStoreEncoder;
exports.getDataStoreInitInfoCodec = getDataStoreInitInfoCodec;
exports.getDataStoreInitInfoDecoder = getDataStoreInitInfoDecoder;
exports.getDataStoreInitInfoEncoder = getDataStoreInitInfoEncoder;
exports.getDataStoreUpdateInfoCodec = getDataStoreUpdateInfoCodec;
exports.getDataStoreUpdateInfoDecoder = getDataStoreUpdateInfoDecoder;
exports.getDataStoreUpdateInfoEncoder = getDataStoreUpdateInfoEncoder;
exports.getDecompressV1DiscriminatorBytes = getDecompressV1DiscriminatorBytes;
exports.getDecompressV1Instruction = getDecompressV1Instruction;
exports.getDecompressV1InstructionDataCodec = getDecompressV1InstructionDataCodec;
exports.getDecompressV1InstructionDataDecoder = getDecompressV1InstructionDataDecoder;
exports.getDecompressV1InstructionDataEncoder = getDecompressV1InstructionDataEncoder;
exports.getEditionCodec = getEditionCodec;
exports.getEditionDecoder = getEditionDecoder;
exports.getEditionEncoder = getEditionEncoder;
exports.getExternalCheckResultCodec = getExternalCheckResultCodec;
exports.getExternalCheckResultDecoder = getExternalCheckResultDecoder;
exports.getExternalCheckResultEncoder = getExternalCheckResultEncoder;
exports.getExternalPluginAdapterCodec = getExternalPluginAdapterCodec;
exports.getExternalPluginAdapterDecoder = getExternalPluginAdapterDecoder;
exports.getExternalPluginAdapterEncoder = getExternalPluginAdapterEncoder;
exports.getExternalPluginAdapterInitInfoCodec = getExternalPluginAdapterInitInfoCodec;
exports.getExternalPluginAdapterInitInfoDecoder = getExternalPluginAdapterInitInfoDecoder;
exports.getExternalPluginAdapterInitInfoEncoder = getExternalPluginAdapterInitInfoEncoder;
exports.getExternalPluginAdapterKeyCodec = getExternalPluginAdapterKeyCodec;
exports.getExternalPluginAdapterKeyDecoder = getExternalPluginAdapterKeyDecoder;
exports.getExternalPluginAdapterKeyEncoder = getExternalPluginAdapterKeyEncoder;
exports.getExternalPluginAdapterSchemaCodec = getExternalPluginAdapterSchemaCodec;
exports.getExternalPluginAdapterSchemaDecoder = getExternalPluginAdapterSchemaDecoder;
exports.getExternalPluginAdapterSchemaEncoder = getExternalPluginAdapterSchemaEncoder;
exports.getExternalPluginAdapterTypeCodec = getExternalPluginAdapterTypeCodec;
exports.getExternalPluginAdapterTypeDecoder = getExternalPluginAdapterTypeDecoder;
exports.getExternalPluginAdapterTypeEncoder = getExternalPluginAdapterTypeEncoder;
exports.getExternalPluginAdapterUpdateInfoCodec = getExternalPluginAdapterUpdateInfoCodec;
exports.getExternalPluginAdapterUpdateInfoDecoder = getExternalPluginAdapterUpdateInfoDecoder;
exports.getExternalPluginAdapterUpdateInfoEncoder = getExternalPluginAdapterUpdateInfoEncoder;
exports.getExternalRegistryRecordCodec = getExternalRegistryRecordCodec;
exports.getExternalRegistryRecordDecoder = getExternalRegistryRecordDecoder;
exports.getExternalRegistryRecordEncoder = getExternalRegistryRecordEncoder;
exports.getExternalValidationResultCodec = getExternalValidationResultCodec;
exports.getExternalValidationResultDecoder = getExternalValidationResultDecoder;
exports.getExternalValidationResultEncoder = getExternalValidationResultEncoder;
exports.getExtraAccountCodec = getExtraAccountCodec;
exports.getExtraAccountDecoder = getExtraAccountDecoder;
exports.getExtraAccountEncoder = getExtraAccountEncoder;
exports.getFreezeDelegateCodec = getFreezeDelegateCodec;
exports.getFreezeDelegateDecoder = getFreezeDelegateDecoder;
exports.getFreezeDelegateEncoder = getFreezeDelegateEncoder;
exports.getHashablePluginSchemaCodec = getHashablePluginSchemaCodec;
exports.getHashablePluginSchemaDecoder = getHashablePluginSchemaDecoder;
exports.getHashablePluginSchemaEncoder = getHashablePluginSchemaEncoder;
exports.getHashedAssetSchemaCodec = getHashedAssetSchemaCodec;
exports.getHashedAssetSchemaDecoder = getHashedAssetSchemaDecoder;
exports.getHashedAssetSchemaEncoder = getHashedAssetSchemaEncoder;
exports.getHashedAssetV1Codec = getHashedAssetV1Codec;
exports.getHashedAssetV1Decoder = getHashedAssetV1Decoder;
exports.getHashedAssetV1Encoder = getHashedAssetV1Encoder;
exports.getHashedAssetV1Size = getHashedAssetV1Size;
exports.getHookableLifecycleEventCodec = getHookableLifecycleEventCodec;
exports.getHookableLifecycleEventDecoder = getHookableLifecycleEventDecoder;
exports.getHookableLifecycleEventEncoder = getHookableLifecycleEventEncoder;
exports.getImmutableMetadataCodec = getImmutableMetadataCodec;
exports.getImmutableMetadataDecoder = getImmutableMetadataDecoder;
exports.getImmutableMetadataEncoder = getImmutableMetadataEncoder;
exports.getKeyCodec = getKeyCodec;
exports.getKeyDecoder = getKeyDecoder;
exports.getKeyEncoder = getKeyEncoder;
exports.getLifecycleHookCodec = getLifecycleHookCodec;
exports.getLifecycleHookDecoder = getLifecycleHookDecoder;
exports.getLifecycleHookEncoder = getLifecycleHookEncoder;
exports.getLifecycleHookInitInfoCodec = getLifecycleHookInitInfoCodec;
exports.getLifecycleHookInitInfoDecoder = getLifecycleHookInitInfoDecoder;
exports.getLifecycleHookInitInfoEncoder = getLifecycleHookInitInfoEncoder;
exports.getLifecycleHookUpdateInfoCodec = getLifecycleHookUpdateInfoCodec;
exports.getLifecycleHookUpdateInfoDecoder = getLifecycleHookUpdateInfoDecoder;
exports.getLifecycleHookUpdateInfoEncoder = getLifecycleHookUpdateInfoEncoder;
exports.getMasterEditionCodec = getMasterEditionCodec;
exports.getMasterEditionDecoder = getMasterEditionDecoder;
exports.getMasterEditionEncoder = getMasterEditionEncoder;
exports.getMplCoreProgramErrorMessage = getMplCoreProgramErrorMessage;
exports.getOracleCodec = getOracleCodec;
exports.getOracleDecoder = getOracleDecoder;
exports.getOracleEncoder = getOracleEncoder;
exports.getOracleInitInfoCodec = getOracleInitInfoCodec;
exports.getOracleInitInfoDecoder = getOracleInitInfoDecoder;
exports.getOracleInitInfoEncoder = getOracleInitInfoEncoder;
exports.getOracleUpdateInfoCodec = getOracleUpdateInfoCodec;
exports.getOracleUpdateInfoDecoder = getOracleUpdateInfoDecoder;
exports.getOracleUpdateInfoEncoder = getOracleUpdateInfoEncoder;
exports.getOracleValidationCodec = getOracleValidationCodec;
exports.getOracleValidationDecoder = getOracleValidationDecoder;
exports.getOracleValidationEncoder = getOracleValidationEncoder;
exports.getPermanentBurnDelegateCodec = getPermanentBurnDelegateCodec;
exports.getPermanentBurnDelegateDecoder = getPermanentBurnDelegateDecoder;
exports.getPermanentBurnDelegateEncoder = getPermanentBurnDelegateEncoder;
exports.getPermanentFreezeDelegateCodec = getPermanentFreezeDelegateCodec;
exports.getPermanentFreezeDelegateDecoder = getPermanentFreezeDelegateDecoder;
exports.getPermanentFreezeDelegateEncoder = getPermanentFreezeDelegateEncoder;
exports.getPermanentTransferDelegateCodec = getPermanentTransferDelegateCodec;
exports.getPermanentTransferDelegateDecoder = getPermanentTransferDelegateDecoder;
exports.getPermanentTransferDelegateEncoder = getPermanentTransferDelegateEncoder;
exports.getPluginAuthorityPairCodec = getPluginAuthorityPairCodec;
exports.getPluginAuthorityPairDecoder = getPluginAuthorityPairDecoder;
exports.getPluginAuthorityPairEncoder = getPluginAuthorityPairEncoder;
exports.getPluginCodec = getPluginCodec;
exports.getPluginDecoder = getPluginDecoder;
exports.getPluginEncoder = getPluginEncoder;
exports.getPluginHeaderV1Codec = getPluginHeaderV1Codec;
exports.getPluginHeaderV1Decoder = getPluginHeaderV1Decoder;
exports.getPluginHeaderV1Encoder = getPluginHeaderV1Encoder;
exports.getPluginHeaderV1Size = getPluginHeaderV1Size;
exports.getPluginRegistryV1Codec = getPluginRegistryV1Codec;
exports.getPluginRegistryV1Decoder = getPluginRegistryV1Decoder;
exports.getPluginRegistryV1Encoder = getPluginRegistryV1Encoder;
exports.getPluginTypeCodec = getPluginTypeCodec;
exports.getPluginTypeDecoder = getPluginTypeDecoder;
exports.getPluginTypeEncoder = getPluginTypeEncoder;
exports.getRegistryRecordCodec = getRegistryRecordCodec;
exports.getRegistryRecordDecoder = getRegistryRecordDecoder;
exports.getRegistryRecordEncoder = getRegistryRecordEncoder;
exports.getRemoveCollectionExternalPluginAdapterV1DiscriminatorBytes = getRemoveCollectionExternalPluginAdapterV1DiscriminatorBytes;
exports.getRemoveCollectionExternalPluginAdapterV1Instruction = getRemoveCollectionExternalPluginAdapterV1Instruction;
exports.getRemoveCollectionExternalPluginAdapterV1InstructionDataCodec = getRemoveCollectionExternalPluginAdapterV1InstructionDataCodec;
exports.getRemoveCollectionExternalPluginAdapterV1InstructionDataDecoder = getRemoveCollectionExternalPluginAdapterV1InstructionDataDecoder;
exports.getRemoveCollectionExternalPluginAdapterV1InstructionDataEncoder = getRemoveCollectionExternalPluginAdapterV1InstructionDataEncoder;
exports.getRemoveCollectionPluginV1DiscriminatorBytes = getRemoveCollectionPluginV1DiscriminatorBytes;
exports.getRemoveCollectionPluginV1Instruction = getRemoveCollectionPluginV1Instruction;
exports.getRemoveCollectionPluginV1InstructionDataCodec = getRemoveCollectionPluginV1InstructionDataCodec;
exports.getRemoveCollectionPluginV1InstructionDataDecoder = getRemoveCollectionPluginV1InstructionDataDecoder;
exports.getRemoveCollectionPluginV1InstructionDataEncoder = getRemoveCollectionPluginV1InstructionDataEncoder;
exports.getRemoveExternalPluginAdapterV1DiscriminatorBytes = getRemoveExternalPluginAdapterV1DiscriminatorBytes;
exports.getRemoveExternalPluginAdapterV1Instruction = getRemoveExternalPluginAdapterV1Instruction;
exports.getRemoveExternalPluginAdapterV1InstructionDataCodec = getRemoveExternalPluginAdapterV1InstructionDataCodec;
exports.getRemoveExternalPluginAdapterV1InstructionDataDecoder = getRemoveExternalPluginAdapterV1InstructionDataDecoder;
exports.getRemoveExternalPluginAdapterV1InstructionDataEncoder = getRemoveExternalPluginAdapterV1InstructionDataEncoder;
exports.getRemovePluginV1DiscriminatorBytes = getRemovePluginV1DiscriminatorBytes;
exports.getRemovePluginV1Instruction = getRemovePluginV1Instruction;
exports.getRemovePluginV1InstructionDataCodec = getRemovePluginV1InstructionDataCodec;
exports.getRemovePluginV1InstructionDataDecoder = getRemovePluginV1InstructionDataDecoder;
exports.getRemovePluginV1InstructionDataEncoder = getRemovePluginV1InstructionDataEncoder;
exports.getRevokeCollectionPluginAuthorityV1DiscriminatorBytes = getRevokeCollectionPluginAuthorityV1DiscriminatorBytes;
exports.getRevokeCollectionPluginAuthorityV1Instruction = getRevokeCollectionPluginAuthorityV1Instruction;
exports.getRevokeCollectionPluginAuthorityV1InstructionDataCodec = getRevokeCollectionPluginAuthorityV1InstructionDataCodec;
exports.getRevokeCollectionPluginAuthorityV1InstructionDataDecoder = getRevokeCollectionPluginAuthorityV1InstructionDataDecoder;
exports.getRevokeCollectionPluginAuthorityV1InstructionDataEncoder = getRevokeCollectionPluginAuthorityV1InstructionDataEncoder;
exports.getRevokePluginAuthorityV1DiscriminatorBytes = getRevokePluginAuthorityV1DiscriminatorBytes;
exports.getRevokePluginAuthorityV1Instruction = getRevokePluginAuthorityV1Instruction;
exports.getRevokePluginAuthorityV1InstructionDataCodec = getRevokePluginAuthorityV1InstructionDataCodec;
exports.getRevokePluginAuthorityV1InstructionDataDecoder = getRevokePluginAuthorityV1InstructionDataDecoder;
exports.getRevokePluginAuthorityV1InstructionDataEncoder = getRevokePluginAuthorityV1InstructionDataEncoder;
exports.getRoyaltiesCodec = getRoyaltiesCodec;
exports.getRoyaltiesDecoder = getRoyaltiesDecoder;
exports.getRoyaltiesEncoder = getRoyaltiesEncoder;
exports.getRuleSetCodec = getRuleSetCodec;
exports.getRuleSetDecoder = getRuleSetDecoder;
exports.getRuleSetEncoder = getRuleSetEncoder;
exports.getSeedCodec = getSeedCodec;
exports.getSeedDecoder = getSeedDecoder;
exports.getSeedEncoder = getSeedEncoder;
exports.getTransferDelegateCodec = getTransferDelegateCodec;
exports.getTransferDelegateDecoder = getTransferDelegateDecoder;
exports.getTransferDelegateEncoder = getTransferDelegateEncoder;
exports.getTransferV1DiscriminatorBytes = getTransferV1DiscriminatorBytes;
exports.getTransferV1Instruction = getTransferV1Instruction;
exports.getTransferV1InstructionDataCodec = getTransferV1InstructionDataCodec;
exports.getTransferV1InstructionDataDecoder = getTransferV1InstructionDataDecoder;
exports.getTransferV1InstructionDataEncoder = getTransferV1InstructionDataEncoder;
exports.getUpdateAuthorityCodec = getUpdateAuthorityCodec;
exports.getUpdateAuthorityDecoder = getUpdateAuthorityDecoder;
exports.getUpdateAuthorityEncoder = getUpdateAuthorityEncoder;
exports.getUpdateCollectionExternalPluginAdapterV1DiscriminatorBytes = getUpdateCollectionExternalPluginAdapterV1DiscriminatorBytes;
exports.getUpdateCollectionExternalPluginAdapterV1Instruction = getUpdateCollectionExternalPluginAdapterV1Instruction;
exports.getUpdateCollectionExternalPluginAdapterV1InstructionDataCodec = getUpdateCollectionExternalPluginAdapterV1InstructionDataCodec;
exports.getUpdateCollectionExternalPluginAdapterV1InstructionDataDecoder = getUpdateCollectionExternalPluginAdapterV1InstructionDataDecoder;
exports.getUpdateCollectionExternalPluginAdapterV1InstructionDataEncoder = getUpdateCollectionExternalPluginAdapterV1InstructionDataEncoder;
exports.getUpdateCollectionPluginV1DiscriminatorBytes = getUpdateCollectionPluginV1DiscriminatorBytes;
exports.getUpdateCollectionPluginV1Instruction = getUpdateCollectionPluginV1Instruction;
exports.getUpdateCollectionPluginV1InstructionDataCodec = getUpdateCollectionPluginV1InstructionDataCodec;
exports.getUpdateCollectionPluginV1InstructionDataDecoder = getUpdateCollectionPluginV1InstructionDataDecoder;
exports.getUpdateCollectionPluginV1InstructionDataEncoder = getUpdateCollectionPluginV1InstructionDataEncoder;
exports.getUpdateCollectionV1DiscriminatorBytes = getUpdateCollectionV1DiscriminatorBytes;
exports.getUpdateCollectionV1Instruction = getUpdateCollectionV1Instruction;
exports.getUpdateCollectionV1InstructionDataCodec = getUpdateCollectionV1InstructionDataCodec;
exports.getUpdateCollectionV1InstructionDataDecoder = getUpdateCollectionV1InstructionDataDecoder;
exports.getUpdateCollectionV1InstructionDataEncoder = getUpdateCollectionV1InstructionDataEncoder;
exports.getUpdateDelegateCodec = getUpdateDelegateCodec;
exports.getUpdateDelegateDecoder = getUpdateDelegateDecoder;
exports.getUpdateDelegateEncoder = getUpdateDelegateEncoder;
exports.getUpdateExternalPluginAdapterV1DiscriminatorBytes = getUpdateExternalPluginAdapterV1DiscriminatorBytes;
exports.getUpdateExternalPluginAdapterV1Instruction = getUpdateExternalPluginAdapterV1Instruction;
exports.getUpdateExternalPluginAdapterV1InstructionDataCodec = getUpdateExternalPluginAdapterV1InstructionDataCodec;
exports.getUpdateExternalPluginAdapterV1InstructionDataDecoder = getUpdateExternalPluginAdapterV1InstructionDataDecoder;
exports.getUpdateExternalPluginAdapterV1InstructionDataEncoder = getUpdateExternalPluginAdapterV1InstructionDataEncoder;
exports.getUpdatePluginV1DiscriminatorBytes = getUpdatePluginV1DiscriminatorBytes;
exports.getUpdatePluginV1Instruction = getUpdatePluginV1Instruction;
exports.getUpdatePluginV1InstructionDataCodec = getUpdatePluginV1InstructionDataCodec;
exports.getUpdatePluginV1InstructionDataDecoder = getUpdatePluginV1InstructionDataDecoder;
exports.getUpdatePluginV1InstructionDataEncoder = getUpdatePluginV1InstructionDataEncoder;
exports.getUpdateV1DiscriminatorBytes = getUpdateV1DiscriminatorBytes;
exports.getUpdateV1Instruction = getUpdateV1Instruction;
exports.getUpdateV1InstructionDataCodec = getUpdateV1InstructionDataCodec;
exports.getUpdateV1InstructionDataDecoder = getUpdateV1InstructionDataDecoder;
exports.getUpdateV1InstructionDataEncoder = getUpdateV1InstructionDataEncoder;
exports.getValidationResultCodec = getValidationResultCodec;
exports.getValidationResultDecoder = getValidationResultDecoder;
exports.getValidationResultEncoder = getValidationResultEncoder;
exports.getValidationResultsOffsetCodec = getValidationResultsOffsetCodec;
exports.getValidationResultsOffsetDecoder = getValidationResultsOffsetDecoder;
exports.getValidationResultsOffsetEncoder = getValidationResultsOffsetEncoder;
exports.getVerifiedCreatorsCodec = getVerifiedCreatorsCodec;
exports.getVerifiedCreatorsDecoder = getVerifiedCreatorsDecoder;
exports.getVerifiedCreatorsEncoder = getVerifiedCreatorsEncoder;
exports.getVerifiedCreatorsSignatureCodec = getVerifiedCreatorsSignatureCodec;
exports.getVerifiedCreatorsSignatureDecoder = getVerifiedCreatorsSignatureDecoder;
exports.getVerifiedCreatorsSignatureEncoder = getVerifiedCreatorsSignatureEncoder;
exports.getWriteCollectionExternalPluginAdapterDataV1DiscriminatorBytes = getWriteCollectionExternalPluginAdapterDataV1DiscriminatorBytes;
exports.getWriteCollectionExternalPluginAdapterDataV1Instruction = getWriteCollectionExternalPluginAdapterDataV1Instruction;
exports.getWriteCollectionExternalPluginAdapterDataV1InstructionDataCodec = getWriteCollectionExternalPluginAdapterDataV1InstructionDataCodec;
exports.getWriteCollectionExternalPluginAdapterDataV1InstructionDataDecoder = getWriteCollectionExternalPluginAdapterDataV1InstructionDataDecoder;
exports.getWriteCollectionExternalPluginAdapterDataV1InstructionDataEncoder = getWriteCollectionExternalPluginAdapterDataV1InstructionDataEncoder;
exports.getWriteExternalPluginAdapterDataV1DiscriminatorBytes = getWriteExternalPluginAdapterDataV1DiscriminatorBytes;
exports.getWriteExternalPluginAdapterDataV1Instruction = getWriteExternalPluginAdapterDataV1Instruction;
exports.getWriteExternalPluginAdapterDataV1InstructionDataCodec = getWriteExternalPluginAdapterDataV1InstructionDataCodec;
exports.getWriteExternalPluginAdapterDataV1InstructionDataDecoder = getWriteExternalPluginAdapterDataV1InstructionDataDecoder;
exports.getWriteExternalPluginAdapterDataV1InstructionDataEncoder = getWriteExternalPluginAdapterDataV1InstructionDataEncoder;
exports.identifyMplCoreProgramInstruction = identifyMplCoreProgramInstruction;
exports.isAuthority = isAuthority;
exports.isExternalPluginAdapter = isExternalPluginAdapter;
exports.isExternalPluginAdapterInitInfo = isExternalPluginAdapterInitInfo;
exports.isExternalPluginAdapterKey = isExternalPluginAdapterKey;
exports.isExternalPluginAdapterUpdateInfo = isExternalPluginAdapterUpdateInfo;
exports.isExtraAccount = isExtraAccount;
exports.isMplCoreProgramError = isMplCoreProgramError;
exports.isOracleValidation = isOracleValidation;
exports.isPlugin = isPlugin;
exports.isRuleSet = isRuleSet;
exports.isSeed = isSeed;
exports.isUpdateAuthority = isUpdateAuthority;
exports.isValidationResultsOffset = isValidationResultsOffset;
exports.oracleValidation = oracleValidation;
exports.parseAddCollectionExternalPluginAdapterV1Instruction = parseAddCollectionExternalPluginAdapterV1Instruction;
exports.parseAddCollectionPluginV1Instruction = parseAddCollectionPluginV1Instruction;
exports.parseAddExternalPluginAdapterV1Instruction = parseAddExternalPluginAdapterV1Instruction;
exports.parseAddPluginV1Instruction = parseAddPluginV1Instruction;
exports.parseApproveCollectionPluginAuthorityV1Instruction = parseApproveCollectionPluginAuthorityV1Instruction;
exports.parseApprovePluginAuthorityV1Instruction = parseApprovePluginAuthorityV1Instruction;
exports.parseBurnCollectionV1Instruction = parseBurnCollectionV1Instruction;
exports.parseBurnV1Instruction = parseBurnV1Instruction;
exports.parseCollectInstruction = parseCollectInstruction;
exports.parseCompressV1Instruction = parseCompressV1Instruction;
exports.parseCreateCollectionV1Instruction = parseCreateCollectionV1Instruction;
exports.parseCreateCollectionV2Instruction = parseCreateCollectionV2Instruction;
exports.parseCreateV1Instruction = parseCreateV1Instruction;
exports.parseCreateV2Instruction = parseCreateV2Instruction;
exports.parseDecompressV1Instruction = parseDecompressV1Instruction;
exports.parseRemoveCollectionExternalPluginAdapterV1Instruction = parseRemoveCollectionExternalPluginAdapterV1Instruction;
exports.parseRemoveCollectionPluginV1Instruction = parseRemoveCollectionPluginV1Instruction;
exports.parseRemoveExternalPluginAdapterV1Instruction = parseRemoveExternalPluginAdapterV1Instruction;
exports.parseRemovePluginV1Instruction = parseRemovePluginV1Instruction;
exports.parseRevokeCollectionPluginAuthorityV1Instruction = parseRevokeCollectionPluginAuthorityV1Instruction;
exports.parseRevokePluginAuthorityV1Instruction = parseRevokePluginAuthorityV1Instruction;
exports.parseTransferV1Instruction = parseTransferV1Instruction;
exports.parseUpdateCollectionExternalPluginAdapterV1Instruction = parseUpdateCollectionExternalPluginAdapterV1Instruction;
exports.parseUpdateCollectionPluginV1Instruction = parseUpdateCollectionPluginV1Instruction;
exports.parseUpdateCollectionV1Instruction = parseUpdateCollectionV1Instruction;
exports.parseUpdateExternalPluginAdapterV1Instruction = parseUpdateExternalPluginAdapterV1Instruction;
exports.parseUpdatePluginV1Instruction = parseUpdatePluginV1Instruction;
exports.parseUpdateV1Instruction = parseUpdateV1Instruction;
exports.parseWriteCollectionExternalPluginAdapterDataV1Instruction = parseWriteCollectionExternalPluginAdapterDataV1Instruction;
exports.parseWriteExternalPluginAdapterDataV1Instruction = parseWriteExternalPluginAdapterDataV1Instruction;
exports.plugin = plugin;
exports.ruleSet = ruleSet;
exports.seed = seed;
exports.updateAuthority = updateAuthority;
exports.validationResultsOffset = validationResultsOffset;
//# sourceMappingURL=index.js.map
//# sourceMappingURL=index.js.map